# Copyright 2012, 2013 Canonical Ltd.
# This software is licensed under the GNU Affero General Public License
# version 3 (see the file LICENSE).

from u1testutils.sso import data

from acceptance import base, helpers, pages


class TestRequestOneTeam(base.IdentityProviderSSTTestCase):

    requested_teams = ['ubuntu-phone']
    expected_teams = ['ubuntu-phone']

    def setUp(self):
        super(TestRequestOneTeam, self).setUp()
        if helpers.is_production() or helpers.is_staging():
            self.skipTest("On staging and production we can't "
                          "access the test consumer.")
        self.user = data.User.make_from_configuration()

    def test_request_teams(self):
        consumer_page = pages.Consumer(open_page=True)
        log_in_page = consumer_page.begin(teams=self.requested_teams)
        site_not_recognized_page = log_in_page.log_in_to_site_not_recognized(
            self.user)
        site_not_recognized_page.make_all_information_available_to_website()
        site_not_recognized_page.yes_sign_me_in()
        consumer_finish_page = pages.ConsumerFinish()
        teams = consumer_finish_page.get_teams()
        self.assertEqual(sorted(teams), sorted(self.expected_teams))


class TestRequestAllTeams(TestRequestOneTeam):

    requested_teams = ['canonical-payment-service-testers', 'ubuntu-phone']
    expected_teams = ['canonical-payment-service-testers', 'ubuntu-phone']


class TestRequestTeamWithNoMembership(TestRequestOneTeam):

    requested_teams = [
        'canonical-payment-service-testers', 'ubuntu-phone', 'canonical-isd',
        'canonical']
    expected_teams = ['canonical-payment-service-testers', 'ubuntu-phone']


class TestRequestNonExistingTeam(TestRequestOneTeam):

    requested_teams = ['non-existing-team']
    expected_teams = []
