# Copyright 2013 Canonical Ltd.
# This software is licensed under the GNU Affero General Public License
# version 3 (see the file LICENSE).

import fixtures
from oath import hotp
from sst import loaders

from acceptance import pages


discover = loaders.discoverRegularTests


# Set up and clean up fixtures for devices tests.

class AuthenticationDevicesPageOpenedWithDevicesAdded(fixtures.Fixture):

    def __init__(self, device_names):
        super(AuthenticationDevicesPageOpenedWithDevicesAdded, self).__init__()
        self.device_names = device_names
        self.key_list = []

    def setUp(self):
        super(AuthenticationDevicesPageOpenedWithDevicesAdded, self).setUp()
        devices_page = pages.YourAuthenticationDevices(open_page=True)
        for name in self.device_names:
            add_device_page = devices_page.add_new_authentication_device()
            add_generic_device_page = add_device_page.add_generic_device()
            aes_key = add_generic_device_page.get_key()
            one_time_password = hotp(aes_key, 0)
            self.key_list.append(aes_key)  # in order to use the keys again
            # We are currently creating users for each test, so no need to
            # clean up the devices added. If we start using existing users,
            # then we will need to add the clean up.
            devices_page = add_generic_device_page.add_device(
                name, one_time_password)

    def get_one_time_password(self, device_number, password_index):
        aes_key = self.key_list[device_number]
        return hotp(aes_key, password_index)


class DeleteDevicesPageOpened(fixtures.Fixture):

    def __init__(self, device_name='Device to delete'):
        super(DeleteDevicesPageOpened, self).__init__()
        self.device_name = device_name

    def setUp(self):
        super(DeleteDevicesPageOpened, self).setUp()
        self.useFixture(
            AuthenticationDevicesPageOpenedWithDevicesAdded(
                [self.device_name]))
        your_auth_devices_page = pages.YourAuthenticationDevices(
            open_page=False)
        your_auth_devices_page.delete_authentication_device()


class RenameDevicePageOpened(fixtures.Fixture):

    def __init__(self, device_name='Device to Rename'):
        super(RenameDevicePageOpened, self).__init__()
        self.device_name = device_name

    def setUp(self):
        super(RenameDevicePageOpened, self).setUp()
        self.useFixture(
            AuthenticationDevicesPageOpenedWithDevicesAdded(
                [self.device_name]))
        your_auth_devices_page = pages.YourAuthenticationDevices(
            open_page=False)
        your_auth_devices_page.rename_authentication_device()


class TwoFactorPageOpenedWithTwoFactorRequired(fixtures.Fixture):

    def __init__(self, device_names=None, user=None):
        super(TwoFactorPageOpenedWithTwoFactorRequired, self).__init__()
        if device_names is None:
            device_names = ['2F Required Generic Device']
        self.device_names = device_names
        self.user = user

    def setUp(self):
        super(TwoFactorPageOpenedWithTwoFactorRequired, self).setUp()
        self.devices_fix = self.useFixture(
            AuthenticationDevicesPageOpenedWithDevicesAdded(
                self.device_names))
        devices_page = pages.YourAuthenticationDevices(
            open_page=False)
        your_account_page = devices_page.menu.go_to_your_account()
        your_account_page.set_twofactor_to_always_required()
        your_account_page.click_update_button()
        logout_landing_page = your_account_page.log_out()
        login_page = logout_landing_page.click_log_in_or_create_account()
        login_page.log_in_with_two_factor(self.user)

    def get_one_time_password(self, device_number, password_index):
        return self.devices_fix.get_one_time_password(
            device_number, password_index)
