# Ensure that trying to get non-utf-encoded URLs results in
# HTTP 400 (bad request) and not a 500/oops.
import requests
from sst.actions import (
    assert_text_contains,
    go_to
)
from u1testutils.sst import config

from acceptance import helpers

base_url = config.get_base_url_from_env()
config.set_base_url_from_env()

# Is root working OK?
go_to('')
assert_text_contains('content', 'One account to log in')

# Try nonexistent url.
go_to("weird")
# We can either get (in dev or debugging mode) Django's 404 page...
if helpers.is_devel():
    assert_text_contains('summary', "Page not found")
# ... or the "Lost something?" page in production or staging mode.
else:
    assert_text_contains('content', "Lost something?")
# Try malformed request. Use requests because we care about the
# HTTP status and it's not easy to get with Selenium/Firefox.
response = requests.get(base_url + "/weird%C0")

# Should return 400 (malformed request).
assert response.status_code == 400

# Should not contain OOPS-ID
assert "OOPS-ID" not in response.content
