import logging
import os
import random
from urlparse import urlparse

from versioninfo import version_info

# /srv/login.staging.ubuntu.com/staging/canonical-identity-provider
# /srv/login.ubuntu.com/production/canonical-identity-provider
BASE_DIR = os.path.dirname(os.path.dirname(__file__))
SRC_DIR = os.path.join(BASE_DIR, 'src')

# /srv/login.staging.ubuntu.com
# /srv/login.ubuntu.com
_HOST_DIR = os.path.abspath(
    os.path.join(BASE_DIR, os.path.pardir, os.path.pardir))
HOST_DIR = os.path.abspath(os.getenv('SSO_HOST_DIR', _HOST_DIR))

# /srv/login.staging.ubuntu.com/staging-logs
# /srv/login.ubuntu.com/production-logs
_LOGS_DIR = os.path.abspath(os.path.join(BASE_DIR, os.path.pardir)) + '-logs'
LOGS_DIR = os.path.abspath(os.getenv('SSO_LOGS_DIR', _LOGS_DIR))
OOPS_DIR = os.path.join(LOGS_DIR, 'www-oops')

SSO_ROOT_URL = os.getenv('SSO_ROOT_URL', 'http://example-sso').rstrip('/')
SCHEME, HOSTNAME, _, _, _, _ = parsed_url = urlparse(SSO_ROOT_URL)

# real settings

ABSOLUTE_URL_OVERRIDES = {}
ADMINAUDIT_EMAILS_RECIPIENTS = []
ADMINAUDIT_EMAIL_FROM = 'noreply@ubuntu.com'
ADMINAUDIT_SUMMARY_SUBJECT = 'SSO Admin Audit Summary (%s)' % HOSTNAME
ADMINS = []
ADMIN_FOR = []
ALLOWED_EXTERNAL_OPENID_REDIRECT_DOMAINS = []
ALLOWED_HOSTS = [HOSTNAME]
ALLOWED_INCLUDE_ROOTS = []
API_HOST = 'http://localhost'
if parsed_url.port:
    API_HOST += ':%s' % parsed_url.port
API_URL = '/api/v2'
APPEND_SLASH = True
APP_SERVERS = []
AUTHENTICATION_BACKENDS = [
    'identityprovider.auth.LaunchpadBackend',
    # restore ModelBackend until admin login gets properly fixed
    'django.contrib.auth.backends.ModelBackend',
    'django_openid_auth.auth.OpenIDBackend',
]
AUTH_USER_MODEL = 'auth.User'
CACHES = {
    'default': {
        'LOCATION': '127.0.0.1:11211',
        'BACKEND': 'django.core.cache.backends.memcached.MemcachedCache',
    },
}
CACHE_MIDDLEWARE_ALIAS = 'default'
CACHE_MIDDLEWARE_KEY_PREFIX = ''
CACHE_MIDDLEWARE_SECONDS = 600
CAPTCHA_API_URL = 'http://www.google.com/recaptcha/api'
CAPTCHA_API_URL_SECURE = 'https://www.google.com/recaptcha/api'
CAPTCHA_IMAGE_URL_PATTERN = 'https://www.google.com/recaptcha/api/image?c=%s'
CAPTCHA_PRIVATE_KEY = ''
CAPTCHA_PROXIES = {}
CAPTCHA_PUBLIC_KEY = ''
CAPTCHA_VERIFY_URL = 'http://www.google.com/recaptcha/api/verify'
CAPTCHA_V2_VERIFY_URL = 'https://www.google.com/recaptcha/api/siteverify'
COMBINE = True
COMBO_URL = '/combo/'
COMMENTS_ALLOW_PROFANITIES = False
CRYPTO_SSO_PRIVKEY = None
CSRF_COOKIE_DOMAIN = None
CSRF_COOKIE_HTTPONLY = True
CSRF_COOKIE_NAME = 'csrftoken'
CSRF_COOKIE_PATH = '/'
CSRF_COOKIE_SECURE = True
CSRF_FAILURE_VIEW = 'identityprovider.views.csrf.csrf_failure'
DATABASES = {
    'default': {
        # New in Django 1.6. Default: True. Set this to False if you want to
        # disable Django's transaction management and implement your own.
        'AUTOCOMMIT': True,
        # RemovedInDjango18Warning: TransactionMiddleware is deprecated in
        # favor of ATOMIC_REQUESTS.
        'ATOMIC_REQUESTS': True,
        'CONN_MAX_AGE': 600,
        'ENGINE': 'django.db.backends.postgresql_psycopg2',
        'HOST': 'localhost',
        'NAME': 'identityprovider',
        'PASSWORD': '',
        'PORT': '',
        'TEST': {
            'CHARSET': None,
            'COLLATION': None,
            'MIRROR': None,
            'NAME': None,
        },
        'TIME_ZONE': 'UTC',
        'USER': 'postgres',
    },
    'nop': {
        'ENGINE': 'identityprovider.nop_backend',
        'NAME': '',
        'PORT': '',
        'HOST': '',
        'USER': '',
        'PASSWORD': '',
        'OPTIONS': {},
        'TEST': {
            'NAME': None,
        },
    },
}
DATABASE_ROUTERS = ['identityprovider.routers.ReadOnlyModeRouter']
DATABASE_SLAVES = []
DATETIME_FORMAT = 'N j, Y, P'
DATETIME_INPUT_FORMATS = [
    '%Y-%m-%d %H:%M:%S',
    '%Y-%m-%d %H:%M:%S.%f',
    '%Y-%m-%d %H:%M',
    '%Y-%m-%d',
    '%m/%d/%Y %H:%M:%S',
    '%m/%d/%Y %H:%M:%S.%f',
    '%m/%d/%Y %H:%M',
    '%m/%d/%Y',
    '%m/%d/%y %H:%M:%S',
    '%m/%d/%y %H:%M:%S.%f',
    '%m/%d/%y %H:%M',
    '%m/%d/%y',
]
DATE_FORMAT = 'N j, Y'
DATE_INPUT_FORMATS = [
    '%Y-%m-%d',
    '%m/%d/%Y',
    '%m/%d/%y',
    '%b %d %Y',
    '%b %d, %Y',
    '%d %b %Y',
    '%d %b, %Y',
    '%B %d %Y',
    '%B %d, %Y',
    '%d %B %Y',
    '%d %B, %Y',
]
DBFAILOVER_FLAG_DIR = os.path.join(HOST_DIR, 'tmp')
DEBUG = False
DEBUG_PROPAGATE_EXCEPTIONS = False
DECIMAL_SEPARATOR = '.'
DEFAULT_CHARSET = 'utf-8'
DEFAULT_CONTENT_TYPE = 'text/html'
DEFAULT_EXCEPTION_REPORTER_FILTER = (
    'django.views.debug.SafeExceptionReporterFilter')
DEFAULT_FILE_STORAGE = 'django.core.files.storage.FileSystemStorage'
DEFAULT_FROM_EMAIL = 'webmaster@localhost'
DEFAULT_INDEX_TABLESPACE = ''
DEFAULT_TABLESPACE = ''
DELETE_UNVERIFIED_ACCOUNT_AFTER_DAYS = 180
DISALLOWED_USER_AGENTS = []
EMAIL_ADDRESS_PATTERN = 'isdtest+%s@canonical.com'
EMAIL_BACKEND = 'django.core.mail.backends.smtp.EmailBackend'
EMAIL_HOST = 'localhost'
EMAIL_HOST_PASSWORD = ''
EMAIL_HOST_USER = ''
EMAIL_PORT = 25
EMAIL_SUBJECT_PREFIX = ''
EMAIL_USE_TLS = False
EMAIL_WHITELIST_REGEXP_LIST = []
EMBEDDED_TRUST_ROOT = SSO_ROOT_URL + '/consumer'
FAILED_LOGIN_WINDOW = 300
FEEDBACK_TO_ADDRESS = 'feedback@ubuntu.com'
FILE_CHARSET = 'utf-8'
FILE_UPLOAD_HANDLERS = [
    'django.core.files.uploadhandler.MemoryFileUploadHandler',
    'django.core.files.uploadhandler.TemporaryFileUploadHandler',
]
FILE_UPLOAD_MAX_MEMORY_SIZE = 2621440
FILE_UPLOAD_PERMISSIONS = None
FILE_UPLOAD_TEMP_DIR = None
FIRST_DAY_OF_WEEK = 0
FIXTURE_DIRS = []
FORCE_SCRIPT_NAME = None
FORMAT_MODULE_PATH = None
GARGOYLE_SWITCH_DEFAULTS = {}
GEOIP_PATH = '/usr/share/GeoIP'
GOOGLE_ANALYTICS_ID = 'THE-GOOGLE-ID'
GPGSERVICE_ENDPOINT = None
GPGSERVICE_TIMEOUT = 5
HANDLER_TIMEOUT_MILLIS = 2500
HONEYPOT_FIELD_NAME = 'openid.usernamesecret'
HOTP_BACKWARDS_DRIFT = 0
HOTP_DRIFT = 3
HOTP_SYNC_WINDOW = 20
IGNORABLE_404_URLS = []
IMAP_PASSWORD = ''
IMAP_PORT = 993
IMAP_SERVER = ''
IMAP_USERNAME = ''
IMAP_USE_SSL = True
INSTALLED_APPS = [
    # django
    'django.contrib.admin',
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.messages',
    'django.contrib.sessions',
    'django.contrib.sites',
    'django.contrib.staticfiles',

    # 3rd party
    'adminaudit',
    'django_openid_auth',
    'django_statsd',
    'djangosecure',
    'gargoyle',
    'honeypot',
    'oauth_backend',
    'pgtools',
    'piston',
    'preflight',
    'saml2idp',

    # own apps
    'api',
    'identityprovider',
    'ubuntu_sso_saml',
    'webui',
    'raven.contrib.django.raven_compat',
    'canonical_raven',
]
INTERNAL_IPS = []
LANGUAGES = [
    ['ar', 'Arabic'],
    ['az', 'Azerbaijani'],
    ['bg', 'Bulgarian'],
    ['bn', 'Bengali'],
    ['bs', 'Bosnian'],
    ['ca', 'Catalan'],
    ['cs', 'Czech'],
    ['cy', 'Welsh'],
    ['da', 'Danish'],
    ['de', 'German'],
    ['el', 'Greek'],
    ['en', 'English'],
    ['en-gb', 'British English'],
    ['eo', 'Esperanto'],
    ['es', 'Spanish'],
    ['es-ar', 'Argentinian Spanish'],
    ['es-mx', 'Mexican Spanish'],
    ['es-ni', 'Nicaraguan Spanish'],
    ['et', 'Estonian'],
    ['eu', 'Basque'],
    ['fa', 'Persian'],
    ['fi', 'Finnish'],
    ['fr', 'French'],
    ['fy-nl', 'Frisian'],
    ['ga', 'Irish'],
    ['gl', 'Galician'],
    ['he', 'Hebrew'],
    ['hi', 'Hindi'],
    ['hr', 'Croatian'],
    ['hu', 'Hungarian'],
    ['id', 'Indonesian'],
    ['is', 'Icelandic'],
    ['it', 'Italian'],
    ['ja', 'Japanese'],
    ['ka', 'Georgian'],
    ['kk', 'Kazakh'],
    ['km', 'Khmer'],
    ['kn', 'Kannada'],
    ['ko', 'Korean'],
    ['lt', 'Lithuanian'],
    ['lv', 'Latvian'],
    ['mk', 'Macedonian'],
    ['ml', 'Malayalam'],
    ['mn', 'Mongolian'],
    ['nb', 'Norwegian Bokmal'],
    ['ne', 'Nepali'],
    ['nl', 'Dutch'],
    ['nn', 'Norwegian Nynorsk'],
    ['pa', 'Punjabi'],
    ['pl', 'Polish'],
    ['pt', 'Portuguese'],
    ['pt-br', 'Brazilian Portuguese'],
    ['ro', 'Romanian'],
    ['ru', 'Russian'],
    ['sk', 'Slovak'],
    ['sl', 'Slovenian'],
    ['sq', 'Albanian'],
    ['sr', 'Serbian'],
    ['sr-latn', 'Serbian Latin'],
    ['sv', 'Swedish'],
    ['sw', 'Swahili'],
    ['ta', 'Tamil'],
    ['te', 'Telugu'],
    ['th', 'Thai'],
    ['tr', 'Turkish'],
    ['tt', 'Tatar'],
    ['uk', 'Ukrainian'],
    ['ur', 'Urdu'],
    ['vi', 'Vietnamese'],
    ['zh-cn', 'Simplified Chinese'],
    ['zh-tw', 'Traditional Chinese'],
]
LANGUAGES_BIDI = ['he', 'ar', 'fa']
LANGUAGE_CODE = 'en'
LANGUAGE_COOKIE_NAME = 'django_language'
LANGUAGE_NAMES = {
    'ru': '\xd0\xa0\xd1\x83\xd1\x81\xd1\x81\xd0\xba\xd0\xb8\xd0\xb9',
    'fr': 'Fran\xc3\xa7ais',
    'en': 'English',
    'es-ar': 'Espa\xc3\xb1ol de Argentina',
    'de': 'Deutsch',
    'hu': 'Magyar',
    'zh-cn': '\xe7\xae\x80\xe4\xbd\x93\xe4\xb8\xad\xe6\x96\x87',
    'pt-br': 'Portugu\xc3\xaas do Brasil',
    'es': 'Espa\xc3\xb1ol',
    'pl': 'Polski',
}
LEAKED_PASSWORD_FAQ_URL = (
    'https://one.ubuntu.com/help/faq/'
    'i-received-an-email-saying-i-should-change-my-password-why-is-that/')
LOCALE_PATHS = [
    os.path.join(BASE_DIR, 'branches/translations/locale'),
]
LOGGING = {
    'disable_existing_loggers': False,
    'filters': {},
    'formatters': {
        'simple': {
            'datefmt': None,
            'format': '%(asctime)s %(levelname)s %(name)s %(message)s',
        },
        'verbose': {
            'datefmt': None,
            'format': ('%(asctime)s %(levelname)s %(module)s %(process)d '
                       '%(thread)d %(message)s'),
        },
    },
    'handlers': {
        'file': {
            'filename': os.path.join(LOGS_DIR, 'sso.log'),
            'formatter': 'simple',
            'class': 'logging.FileHandler',
            'filters': '',
            'level': 'INFO',
        },
    },
    'incremental': False,
    'loggers': {
        'sso': {
            'level': 'INFO',
            'propagate': False,
            'filters': [],
            'handlers': ['file'],
        },
        'django': {
            'level': 'INFO',
            'propagate': False,
            'filters': [],
            'handlers': ['file'],
        },
    },
    'root': {
        'level': 'INFO',
        'filters': [],
        'handlers': ['file'],
    },
    'version': 1,
}
LOGGING_CONFIG = 'django.utils.log.dictConfig'
LOGIN_REDIRECT_URL = '/'
LOGIN_URL = '/+login'
LOGOUT_URL = '/accounts/logout/'
LP_API_URL = ''
LP_API_CONSUMER_KEY = ''
LP_API_TOKEN = ''
LP_API_TOKEN_SECRET = ''
MACAROON_TTL = 365 * 24 * 3600  # seconds
MACAROON_SERVICE_LOCATION = HOSTNAME
MANAGERS = []
MAX_FAILED_LOGIN_ATTEMPTS = 20
MAX_PASSWORD_RESET_TOKENS = 5
MEDIA_ROOT = ''
MEDIA_URL = ''
MESSAGE_STORAGE = 'django.contrib.messages.storage.fallback.FallbackStorage'
MIDDLEWARE_CLASSES = [
    ('raven.contrib.django.raven_compat.middleware'
     '.SentryResponseErrorIdMiddleware'),
    'canonical_raven.middleware.RavenContextMiddleware',
    'api.v20.utils.EnsureJSONResponseOnAPIErrorMiddleware',
    'identityprovider.middleware.http.SetRemoteAddrFromForwardedFor',
    'identityprovider.middleware.statsd.PistonRequestTimingMiddleware',
    'django_statsd.middleware.GraphiteMiddleware',
    'identityprovider.middleware.readonly.ReadOnlyMiddleware',
    'identityprovider.middleware.oopsplease.OopsPleaseMiddleware',
    'djangosecure.middleware.SecurityMiddleware',
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.common.CommonMiddleware',
    'identityprovider.middleware.honeypot.HoneypotMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.middleware.clickjacking.XFrameOptionsMiddleware',
    'identityprovider.middleware.useraccount.UserAccountConversionMiddleware',
    'django.middleware.locale.LocaleMiddleware',
]

MONTH_DAY_FORMAT = 'F j'
NOREPLY_FROM_ADDRESS = 'noreply@ubuntu.com'
NOREPLY_FROM_NAME = 'Ubuntu One'
NUMBER_GROUPING = 0
OAUTH_DATA_STORE = 'identityprovider.store.SSODataStore'
OAUTH_ENFORCE_SSL = False
OAUTH_NONCE_TIMEOUT_SECONDS = 3600  # one hour
OAUTH_REQUEST_MAX_AGE_SECONDS = 15 * 60  # 15 minutes
OOPSES = {
    'publishers': [{
        'inherit_id': 'true',
        'error_dir': OOPS_DIR,
        'exchange_name': '',
        'routing_key': '',
        'vhost': '',
        'host': '',
        'only_new': 'true',
        'new_only': '',
        'password': '',
        'type': 'datedir',
        'user': '',
    }],
    'template': {'reporter': 'SSO-DEV'},
}
OPENID_CREATE_USERS = True
OPENID_DISALLOW_INAMES = False
OPENID_EMAIL_WHITELIST_REGEXP_LIST = []
OPENID_FOLLOW_RENAMES = False
OPENID_LAUNCHPAD_STAFF_TEAMS = []
OPENID_LAUNCHPAD_TEAMS_MAPPING = {}
OPENID_LAUNCHPAD_TEAMS_MAPPING_AUTO = False
OPENID_LAUNCHPAD_TEAMS_MAPPING_AUTO_BLACKLIST = []
OPENID_LAUNCHPAD_TEAMS_REQUIRED = []
OPENID_PHYSICAL_MULTIFACTOR_REQUIRED = False
OPENID_PREAUTHORIZATION_ACL = []
OPENID_SREG_EXTRA_FIELDS = ['language']
OPENID_SREG_REQUIRED_FIELDS = []
OPENID_SSO_SERVER_URL = SSO_ROOT_URL
OPENID_STRICT_USERNAMES = False
OPENID_TRUST_ROOT = SSO_ROOT_URL
OPENID_UPDATE_DETAILS_FROM_SREG = True
OPENID_USE_AS_ADMIN_LOGIN = False
PASSWORD_BLACKLIST_FILE = os.path.join(BASE_DIR, "password-blacklist.txt")
PASSWORD_HASHERS = [
    'identityprovider.auth.BCrypt13PasswordHasher',
    'django.contrib.auth.hashers.PBKDF2PasswordHasher',
]
PASSWORD_RESET_TIMEOUT_DAYS = 3
PGCONNECT_TIMEOUT = 10
PISTON_EMAIL_ERRORS = False
PISTON_DISPLAY_ERRORS = False
PREFLIGHT_BASE_TEMPLATE = 'base.html'
PREFLIGHT_TABLE_CLASS = 'listing'
PREPEND_WWW = False
PRE_AUTHORIZATION_VALIDITY = 2
PROFANITIES_LIST = []
PROFILE_FILENAME = 'sso.profile'
PROFILE_PATTERN = '(api|identityprovider|ubuntu_sso_saml|webui)\\..*'
# Used to generate secure random data for e.g. email tokens.
RANDOM_GENERATOR = random.SystemRandom()
RAVEN_CONFIG = {
    # 'dsn': 'http://api:key@sentry.host/project_id',
    'release': version_info['revno'],
    'string_max_length': 16000,
    'CELERY_LOGLEVEL': logging.WARN,
    'processors': [
        'raven.processors.SanitizePasswordsProcessor',
        'raven.processors.RemoveStackLocalsProcessor',
        'raven.processors.RemovePostDataProcessor',
        'canonical_raven.processors.RemoveCookiesProcessor',
        'canonical_raven.processors.SanitizeTimelineDjangoProcessor',
    ],
}
READONLY_SECRET = 'CHANGEME'
READ_ONLY_MODE = False
ROOT_URLCONF = 'django_project.urls'
SAML2IDP_CONFIG = {
    'signing': 'true',
    'issuer': SSO_ROOT_URL,
    'autosubmit': 'true',
}
SAML2IDP_REMOTES = {}
SECRET_KEY = ''
SECURE_BROWSER_XSS_FILTER = True
SECURE_CONTENT_TYPE_NOSNIFF = True
SECURE_FRAME_DENY = False
SECURE_HSTS_INCLUDE_SUBDOMAINS = True
SECURE_HSTS_SECONDS = 15552000
SECURE_PROXY_SSL_HEADER = None
SECURE_SSL_REDIRECT = False
SEND_BROKEN_LINK_EMAILS = False
SENTRY_CELERY_LOGLEVEL = logging.WARN
SERVER_EMAIL = 'noreply@ubuntu.com'
SESSION_CACHE_ALIAS = 'default'
SESSION_COOKIE_AGE = 1209600
SESSION_COOKIE_DOMAIN = None
SESSION_COOKIE_HTTPONLY = True
SESSION_COOKIE_NAME = 'sessionid'
SESSION_COOKIE_PATH = '/'
SESSION_COOKIE_SECURE = True
SESSION_ENGINE = 'django.contrib.sessions.backends.db'
SESSION_EXPIRE_AT_BROWSER_CLOSE = False
SESSION_FILE_PATH = None
SESSION_SAVE_EVERY_REQUEST = False
SESSION_SERIALIZER = 'django.contrib.sessions.serializers.PickleSerializer'
SETTINGS_ENCODING = 'utf-8'
SETTINGS_MODULE = 'django_project.settings'
SHORT_DATETIME_FORMAT = 'm/d/Y P'
SHORT_DATE_FORMAT = 'm/d/Y'
SHOW_USER_NUM_AUTHLOGS = 50
SIGNING_BACKEND = 'django.core.signing.TimestampSigner'
SITE_ID = 1
SSO_ACCOUNT_UPDATE_URL = None
SSO_PROVIDER_URL = SSO_ROOT_URL + '/+openid'
SSO_RESTRICT_RP = False
SSO_TEST_ACCOUNT_EMAIL = ''
SSO_TEST_ACCOUNT_FULL_NAME = ''
SSO_TEST_ACCOUNT_PASSWORD = ''
STATICFILES_DIRS = []
STATICFILES_FINDERS = [
    'django.contrib.staticfiles.finders.FileSystemFinder',
    'django.contrib.staticfiles.finders.AppDirectoriesFinder',
]
STATICFILES_STORAGE = ('identityprovider.storage'
                       '.SSOGzipManifestStaticFilesStorage')
STATIC_ROOT = 'staticfiles'
STATIC_URL = '/assets/'
STATSD_CLIENT = 'django_statsd.clients.normal'
STATSD_PATCHES = ['django_statsd.patches.db', 'django_statsd.patches.cache']
SUPPORTED_LANGUAGES = ['en', 'es', 'pl', 'de', 'zh-cn', 'pt-br', 'ru', 'fr']
SUPPORT_FORM_URL = 'https://forms.canonical.com/sso-support/'
SUPPORT_PHONE = ''
SUSPEND_UNVERIFIED_ACCOUNT_AFTER_DAYS = 90
TEMPLATE_CONTEXT_PROCESSORS = [
    'django.contrib.auth.context_processors.auth',
    'django.contrib.messages.context_processors.messages',
    'django.core.context_processors.i18n',
    'django.core.context_processors.media',
    'django.core.context_processors.static',
    'identityprovider.context_processors.debug',
    'identityprovider.context_processors.readonly',
    'identityprovider.context_processors.i18n',
    'django.core.context_processors.request',
    'identityprovider.context_processors.detect_embedded',
    'identityprovider.context_processors.google_analytics_id',
    'identityprovider.context_processors.current_date',
    'identityprovider.context_processors.combine',
]
TEMPLATE_DEBUG = False
TEMPLATE_DIRS = [
    os.path.join(SRC_DIR, 'api', 'templates'),
    os.path.join(SRC_DIR, 'identityprovider', 'templates'),
    os.path.join(SRC_DIR, 'webui', 'templates'),
]
TEMPLATE_LOADERS = [
    'django.template.loaders.filesystem.Loader',
    'django.template.loaders.app_directories.Loader',
]
TEMPLATE_STRING_IF_INVALID = ''
TERMS_OF_SERVICE_URL = 'https://one.ubuntu.com/terms/'
TESTING = False
THOUSAND_SEPARATOR = ','
THROTTLE_MAX_REQUESTS = 3600
THROTTLE_WHITELIST_EMAIL_REGEXP_LIST = []
TIMELOG_LOG = 'timelog.log'
TIME_FORMAT = 'P'
TIME_INPUT_FORMATS = ['%H:%M:%S', '%H:%M']
TIME_ZONE = 'UTC'
TRANSACTIONS_MANAGED = False
TWOFACTOR_FAILURE_NOTIFICATION_EMAILS = []
TWOFACTOR_FAILURE_NOTIFICATION_TEAMS = []
TWOFACTOR_FAILURE_NOTIFICATION_THRESHOLD = 2
TWOFACTOR_MANDATORY_TEAMS = []
TWOFACTOR_FAQ_URL = 'https://help.ubuntu.com/community/SSO/FAQs/2FA'
TWOFACTOR_FRESHNESS = 15 * 60  # 15 min
TWOFACTOR_MAX_ATTEMPTS = 18
TWOFACTOR_PAPER_CODES = 25
TWOFACTOR_PAPER_CODES_ALLOW_GENERATION = 25
TWOFACTOR_PAPER_CODES_WARN_RENEWAL = 3
TWOFACTOR_SERVICE_IDENT = 'UbuntuSSO'
TWOFACTOR_TTL = 48 * 3600  # 48 hs
USE_ETAGS = False
USE_I18N = True
USE_L10N = True
USE_SENTRY = True
USE_THOUSAND_SEPARATOR = False
USE_TZ = False
USE_X_FORWARDED_HOST = False
WARN_DELETE_UNVERIFIED_ACCOUNT_BEFORE_DAYS = 15
WARN_SUSPEND_UNVERIFIED_ACCOUNT_BEFORE_DAYS = 15
WRITABLE_RO_MODE_MODELS = [
    'sessions.Session',
    'identityprovider.Account',
    'identityprovider.AuthenticationDevice',
    'auth.User',
    'django_openid_auth.Association',
]
WSGI_APPLICATION = 'django_project.wsgi.application'
X_FRAME_OPTIONS = 'SAMEORIGIN'
YEAR_MONTH_FORMAT = 'F Y'
YUBIKEY_PERSONALIZE_URL = 'http://www.yubico.com/personalization-tool'
