# Copyright 2010 Canonical Ltd.  This software is licensed under the
# GNU Affero General Public License version 3 (see the file LICENSE).

from django.conf.urls import include, patterns, url

from piston.authentication import HttpBasicAuthentication
from piston.resource import Resource

from identityprovider.auth import (
    basic_authenticate,
    SSOOAuthAuthentication,
)

import api.v10.handlers as v10
import api.v11.handlers as v11

v10root = Resource(handler=v10.RootHandler)
v10captcha = Resource(handler=v10.CaptchaHandler)
v10registration = Resource(handler=v10.RegistrationHandler)
v10auth = Resource(
    handler=v10.AuthenticationHandler,
    authentication=HttpBasicAuthentication(auth_func=basic_authenticate)
)
# This is the only v1 API that uses OAuth tokens for authentication,
# so we need to allow for V1 tokens.
v10accounts = Resource(
    handler=v10.AccountsHandler,
    authentication=SSOOAuthAuthentication(require_v2_tokens=False)
)


v11root = Resource(handler=v11.RootHandler)
v11auth = Resource(
    handler=v11.AuthenticationHandler,
    authentication=HttpBasicAuthentication(auth_func=basic_authenticate)
)

urlpatterns = patterns(
    '',
    # v1.0
    url(r'^1.0/$', v10root, name='api-10-root',
        kwargs={'emitter_format': 'lazr.restful'}),
    url(r'^1.0/captchas$', v10captcha, name='api-10-captchas',
        kwargs={'emitter_format': 'lazr.restful'}),
    url(r'^1.0/registration$', v10registration, name='api-10-registration',
        kwargs={'emitter_format': 'lazr.restful'}),
    url(r'^1.0/authentications$', v10auth, name='api-10-authentications',
        kwargs={'emitter_format': 'lazr.restful'}),
    url(r'^1.0/accounts$', v10accounts, name='api-10-accounts',
        kwargs={'emitter_format': 'lazr.restful'}),

    # v1.1
    url(r'^1.1/$', v11root,
        kwargs={'emitter_format': 'lazr.restful'}),
    # add backwards compatible endpoints
    url(r'^1.1/captchas$', v10captcha,
        kwargs={'emitter_format': 'lazr.restful'}),
    url(r'^1.1/registration$', v10registration,
        kwargs={'emitter_format': 'lazr.restful'}),
    url(r'^1.1/accounts$', v10accounts,
        kwargs={'emitter_format': 'lazr.restful'}),
    # add overriding endpoints
    url(r'^1.1/authentications$', v11auth,
        kwargs={'emitter_format': 'lazr.restful'}),

    # v2
    url(r'^v2/', include('api.v20.urls')),
)
