# Copyright 2010 Canonical Ltd.  This software is licensed under the
# GNU Affero General Public License version 3 (see the file LICENSE).

from __future__ import unicode_literals

from functools import wraps

from django.http import HttpResponseForbidden

from identityprovider.models import (
    Account,
    APIUser,
)


def api_user_required(func):
    @wraps(func)
    def wrapper(self, request, *args, **kwargs):
        if isinstance(request.user, APIUser):
            return func(self, request, *args, **kwargs)
        response = HttpResponseForbidden('403 Forbidden')
        return response
    return wrapper


def check_leak(func):
    @wraps(func)
    def wrapper(self, request, *args, **kwargs):
        account = request.user
        if isinstance(account, Account) and account.need_password_reset:
            response = HttpResponseForbidden('403 Forbidden')
            return response
        return func(self, request, *args, **kwargs)
    return wrapper


def plain_user_required(func):
    @check_leak
    @wraps(func)
    def wrapper(self, request, *args, **kwargs):
        if isinstance(request.user, Account):
            return func(self, request, *args, **kwargs)
        response = HttpResponseForbidden('403 Forbidden')
        return response
    return wrapper


def named_operation(func):
    func.is_named_operation = True
    return func
