# Copyright 2010 Canonical Ltd.  This software is licensed under the
# GNU Affero General Public License version 3 (see the file LICENSE).

# We use Django forms for webservice input validation

from __future__ import unicode_literals

from django import forms
from django.forms import fields
from django.utils.translation import ugettext_lazy as _

from identityprovider.forms import NewAccountForm
from identityprovider.models.captcha import Captcha


class WebserviceCreateAccountForm(NewAccountForm):
    captcha_id = fields.CharField(max_length=1024)
    captcha_solution = fields.CharField(max_length=256)
    remote_ip = fields.CharField(max_length=256)
    platform = fields.TypedChoiceField(choices=[
        ('web', 'Web'), ('desktop', 'Desktop'), ('mobile', 'Mobile')],
        empty_value='desktop', required=False)
    validate_redirect_to = fields.CharField(required=False)

    def __init__(self, *args, **kwargs):
        if args:
            data = args[0]
            if 'passwordconfirm' not in data:
                data['passwordconfirm'] = data['password']
        super(WebserviceCreateAccountForm, self).__init__(*args, **kwargs)
        # back fields optional for backwards compatibility
        self.fields['displayname'].required = False
        self.fields['accept_tos'].required = False

    def clean_validate_redirect_to(self):
        validate_redirect_to = self.cleaned_data.get('validate_redirect_to')
        # return None instead of '' as the default value
        if not validate_redirect_to:
            validate_redirect_to = None
        return validate_redirect_to

    def clean(self):
        cleaned_data = super(WebserviceCreateAccountForm, self).clean()
        captcha_id = cleaned_data.get('captcha_id')
        captcha_solution = cleaned_data.get('captcha_solution')

        # The remote IP address is absolutely required, and comes from
        # SSO itself, not from the client.  If it's missing, it's a
        # programming error, and should not be returned to the client
        # as a validation error.  So, we use a normal key lookup here.
        remote_ip = cleaned_data['remote_ip']

        captcha = Captcha(captcha_id)
        email = cleaned_data.get('email', '')
        if captcha.verify(captcha_solution, remote_ip, email):
            return cleaned_data
        # not verified
        raise forms.ValidationError(_("Wrong captcha solution."))
