from __future__ import unicode_literals

from django.contrib.auth.models import User
from django.http import HttpResponse
from django.test.client import RequestFactory

from api.v10.decorators import check_leak, plain_user_required
from identityprovider.tests.utils import SSOBaseTestCase


class PlainUserRequiredTestCase(SSOBaseTestCase):
    @plain_user_required
    def plain_user_required_view(self, request):
        return HttpResponse()

    def test_plain_user_required(self):
        request = RequestFactory().get('/')
        request.user = self.factory.make_account()
        response = self.plain_user_required_view(request)
        self.assertEqual(response.status_code, 200)

    def test_plain_user_required_with_leaked_creds(self):
        request = RequestFactory().get('/')
        request.user = self.factory.make_account()
        request.user.need_password_reset = True
        response = self.plain_user_required_view(request)
        self.assertEqual(response.status_code, 403)


class CheckLeakTestCase(SSOBaseTestCase):
    @check_leak
    def check_leak_view(self, request):
        return HttpResponse()

    def test_check_leak_without_leaked_creds(self):
        request = RequestFactory().get('/')
        request.user = self.factory.make_account()
        response = self.check_leak_view(request)
        self.assertEqual(response.status_code, 200)

    def test_check_leak_with_leaked_creds(self):
        request = RequestFactory().get('/')
        request.user = self.factory.make_account()
        request.user.need_password_reset = True
        response = self.check_leak_view(request)
        self.assertEqual(response.status_code, 403)

    def test_check_leak_with_non_account_user(self):
        request = RequestFactory().get('/')
        request.user = User()
        response = self.check_leak_view(request)
        self.assertEqual(response.status_code, 200)
