# -*- coding: utf-8 -*-

# Copyright 2010 Canonical Ltd.  This software is licensed under the
# GNU Affero General Public License version 3 (see the file LICENSE).

from __future__ import unicode_literals

from django.test.utils import override_settings

from api.v10.forms import WebserviceCreateAccountForm
from identityprovider.tests.utils import SSOBaseTestCase


@override_settings(CAPTCHA_PUBLIC_KEY='public', CAPTCHA_PRIVATE_KEY='private')
class WebServiceCreateAccountFormTestCase(SSOBaseTestCase):

    def setUp(self):
        super(WebServiceCreateAccountFormTestCase, self).setUp()
        # patch Captcha so it never hits the real network
        self.mock_captcha_open = self.patch(
            'identityprovider.models.captcha.Captcha._open')
        self.mock_captcha_open.return_value.is_error = False
        self.mock_captcha_open.return_value.data.return_value = 'true\nyey'

    def test_nonascii_password(self):
        data = {'password': 'Curuzú Cuatiá',
                'remote_ip': '127.0.0.1'}
        form = WebserviceCreateAccountForm(data=data)
        self.assertFalse(form.is_valid())
        self.assertEqual(form.errors['password'][0],
                         'Invalid characters in password')

    def test_default_platform(self):
        form = WebserviceCreateAccountForm()
        self.assertEqual(form.fields['platform'].empty_value, 'desktop')

    def test_default_cleaned_platform(self):
        data = {
            'email': 'some@email.com',
            'password': 'password1A',
            'captcha_id': '1',
            'captcha_solution': '2',
            'remote_ip': '127.0.0.1',
        }
        form = WebserviceCreateAccountForm(data)
        self.assertTrue(form.is_valid())
        self.assertEqual(form.cleaned_data['platform'], 'desktop')

    def test_captcha_checked_for_whitelist(self):
        data = {
            'email': 'canonicaltest@gmail.com',
            'password': 'password1A',
            'captcha_id': '1',
            'captcha_solution': '2',
            'remote_ip': '127.0.0.1',
        }
        pattern = '^canonicaltest(?:\+.+)?@gmail\.com$'
        with self.settings(EMAIL_WHITELIST_REGEXP_LIST=[pattern]):
            form = WebserviceCreateAccountForm(data)
            self.assertTrue(form.is_valid())

    def test_default_cleaned_validate_redirect_to(self):
        data = {
            'email': 'some@email.com',
            'password': 'password1A',
            'captcha_id': '1',
            'captcha_solution': '2',
            'remote_ip': '127.0.0.1',
        }
        form = WebserviceCreateAccountForm(data)
        self.assertTrue(form.is_valid())
        self.assertEqual(form.cleaned_data['validate_redirect_to'], None)
