from django.core.urlresolvers import resolve, reverse
from piston.authentication import NoAuthentication

from api.v20 import auth, handlers
from identityprovider.tests.utils import SSOBaseTestCase


class ApiV2UrlsTestCase(SSOBaseTestCase):

    def test_account(self):
        path = reverse('api-account', kwargs=dict(openid='1234567'))
        match = resolve(path)

        self.assertIsInstance(match.func, auth.ApiResource)
        self.assertIsInstance(match.func.handler, handlers.AccountsHandler)

        self.assertEqual(len(match.func.authentication), 1)
        self.assertIsInstance(
            match.func.authentication[0], auth.ApiAccountsAuthentication)

    def test_email(self):
        path = reverse('api-email', kwargs=dict(email='foo@test.com'))
        match = resolve(path)

        self.assertIsInstance(match.func, auth.ApiResource)
        self.assertIsInstance(match.func.handler, handlers.EmailsHandler)

        self.assertEqual(len(match.func.authentication), 1)
        self.assertIsInstance(
            match.func.authentication[0], auth.ApiEmailsAuthentication)

    def test_requests(self):
        path = reverse('api-requests')
        match = resolve(path)

        self.assertIsInstance(match.func, auth.ApiResource)
        self.assertIsInstance(match.func.handler, handlers.RequestsHandler)

        self.assertEqual(len(match.func.authentication), 1)
        self.assertIsInstance(match.func.authentication[0], NoAuthentication)

    def test_login(self):
        path = reverse('api-login')
        match = resolve(path)

        self.assertIsInstance(match.func, auth.ApiResource)
        self.assertIsInstance(match.func.handler, handlers.AccountLoginHandler)

        self.assertEqual(len(match.func.authentication), 1)
        self.assertIsInstance(match.func.authentication[0], NoAuthentication)

    def test_token(self):
        path = reverse('api-token', kwargs=dict(token='foo'))
        match = resolve(path)

        self.assertIsInstance(match.func, auth.ApiResource)
        self.assertIsInstance(match.func.handler, handlers.TokensHandler)

        self.assertEqual(len(match.func.authentication), 1)
        self.assertIsInstance(
            match.func.authentication[0], auth.ApiTokensAuthentication)

    def test_password_reset(self):
        path = reverse('api-password-reset')
        match = resolve(path)

        self.assertIsInstance(match.func, auth.ApiResource)
        self.assertIsInstance(
            match.func.handler, handlers.PasswordResetTokenHandler)

        self.assertEqual(len(match.func.authentication), 1)
        self.assertIsInstance(match.func.authentication[0], NoAuthentication)

    def test_ssh_key_by_email(self):
        path = reverse('api-keys', kwargs=dict(account='foo@test.com'))
        match = resolve(path)

        self.assertIsInstance(match.func, auth.ApiResource)
        self.assertIsInstance(match.func.handler, handlers.SSHKeyHandler)

        self.assertEqual(len(match.func.authentication), 1)
        self.assertIsInstance(match.func.authentication[0], NoAuthentication)
