from django.apps import AppConfig
from django.core.checks import register

from checks import gpgservice_endpoint_check


class IdentityProviderAppConfig(AppConfig):
    name = 'identityprovider'
    verbose_name = 'Identity Provider'

    def ready(self):
        # Import here to ensure settings are already available.
        from identityprovider.utils import populate_password_blacklist
        populate_password_blacklist()
        register(gpgservice_endpoint_check)

        # We need to force load our custom gargoyle conditions as gargoyle's
        # autodiscovery looks for "identityprovider.gargoyle" only,
        # but a file named "identityprovider/gargoyle.py" would in some cases
        # shadow the *real* gargoyle causing hard to debug import errors.
        from identityprovider import gargoyle_conditions  # noqa
