from optparse import make_option

from django.core.management.base import BaseCommand, CommandError

from identityprovider.models import (
    Account,
    EmailAddress,
    Person,
)
from identityprovider.models.const import EmailStatus
from identityprovider.utils import get_object_or_none


class Command(BaseCommand):
    args = 'email'
    option_list = BaseCommand.option_list + (
        make_option('--email', dest='email'),
        make_option('--openid', dest='openid'),
        make_option('--lp-username', dest='lp_username'))
    help = "Add a @canonical.com email to an existing account."

    def handle(self, *args, **kwargs):
        email = kwargs.get('email')
        openid = kwargs.get('openid')
        lp_username = kwargs.get('lp_username')

        # initialze expected vars with defaults
        account = lp_person = None

        if email is not None:
            try:
                account = EmailAddress.objects.get(email=email).account
            except EmailAddress.DoesNotExist:
                raise CommandError(
                    "No account found matching email '%s'." % email)
        elif openid is not None:
            try:
                account = Account.objects.get(openid_identifier=openid)
            except Account.DoesNotExist:
                raise CommandError(
                    "No account found matching openid '%s'." % openid)
        elif lp_username is not None:
            person = get_object_or_none(Person, name=lp_username)
            if person is not None:
                account = person.account
                lp_person = person.pk

            if account is None:
                raise CommandError(
                    "No account found matching LP username '%s'." %
                    lp_username)
        else:
            raise CommandError(
                "Need to specify one of --email, --openid or --lp-username")

        if len(args) < 1:
            raise CommandError("You need to specify an email to add.")
        if len(args) > 1:
            raise CommandError("You can only specify a single email to add.")

        new_email = args[0]
        if not new_email.endswith('@canonical.com'):
            raise CommandError(
                'You can only add @canonical.com email addresses.')
        if EmailAddress.objects.filter(email=new_email).exists():
            raise CommandError(
                "Cannot add given email for it is already claimed.")

        # add the email to the account
        EmailAddress.objects.create(email=new_email, account=account,
                                    status=EmailStatus.VALIDATED,
                                    lp_person=lp_person)
