from optparse import make_option

from django.core.management.base import BaseCommand, CommandError

from identityprovider.models import OpenIDRPConfig


class Command(BaseCommand):
    args = '<trust_root>'
    option_list = BaseCommand.option_list + (
        make_option('--allow-unverified', action="store_true",
                    default=False, dest='allow_unverified'),
        make_option('--allowed-user-attribs', action="store",
                    dest='allowed_user_attribs'),
        make_option('--auto-authorize', action="store_true",
                    default=False, dest='auto_authorize'),
        make_option('--can-query-private-teams', action="store_true",
                    default=False, dest='can_query_any_team'),
    )
    help = "Create OpenID RP config entry."

    def handle(self, *args, **kwargs):
        if len(args) < 1:
            raise CommandError("Need to specify trust_root")

        trust_root = args[0]
        allow_unverified = kwargs.get('allow_unverified', False)
        allowed_user_attribs = kwargs.get('allowed_user_attribs', '')
        auto_authorize = kwargs.get('auto_authorize', False)
        can_query_any_team = kwargs.get('can_query_any_team', False)
        if allowed_user_attribs is None:
            allowed_user_attribs = ''

        try:
            rpconfig = OpenIDRPConfig.objects.get(trust_root=trust_root)
            rpconfig.allow_unverified = allow_unverified
            rpconfig.allowed_user_attribs = allowed_user_attribs
            rpconfig.auto_authorize = auto_authorize
            rpconfig.can_query_any_team = can_query_any_team
            rpconfig.save()
        except OpenIDRPConfig.DoesNotExist:
            OpenIDRPConfig.objects.create(
                trust_root=trust_root,
                allow_unverified=allow_unverified,
                allowed_user_attribs=allowed_user_attribs,
                auto_authorize=auto_authorize,
                can_query_any_team=can_query_any_team,
            )
        except OpenIDRPConfig.MultipleObjectsReturned:
            raise CommandError(
                "Multiple OpenIDRPConfig objects for trust_root '%s'"
                % trust_root)
