from optparse import make_option

from django.core.management.base import BaseCommand, CommandError

from identityprovider.models import (
    Account,
    EmailAddress,
    LPOpenIdIdentifier,
    Person,
    TeamParticipation,
    get_team_memberships_for_user,
)


def get_unique_username():
    i = 0
    while True:
        try:
            username = "user%d" % i
            i += 1
            Person.objects.get(name=username)
        except Person.DoesNotExist:
            break
    return username


def add_user_to_team(account, teamname, nickname=None, create_team=True):
    """Note: will not work on the staging or production databases.

    Those are replicated from LP and read-only.

    """
    memberships = get_team_memberships_for_user([teamname], account, True)
    if len(memberships) > 0:
        return

    p = account.person
    if p is None:
        if nickname is None:
            nickname = get_unique_username()
        p = Person.objects.create(lp_account=account.id,
                                  displayname=account.displayname,
                                  name=nickname)
        del account.person

    try:
        LPOpenIdIdentifier.objects.get(lp_account=account.id)
    except LPOpenIdIdentifier.DoesNotExist:
        LPOpenIdIdentifier.objects.create(
            identifier=account.openid_identifier, lp_account=account.id)

    try:
        t = Person.objects.get(name=teamname)
    except Person.DoesNotExist:
        if not create_team:
            return
        t = Person.objects.create(displayname="Team %s" % teamname,
                                  teamowner=p.id, name=teamname)

    TeamParticipation.objects.create(team=t, person=p)


class Command(BaseCommand):
    args = '<team team ...>'
    option_list = BaseCommand.option_list + (
        make_option('--email', dest='email'),
        make_option('--openid', dest='openid'))
    help = "Link an account and a team."

    def handle(self, *args, **kwargs):
        email = kwargs.get('email')
        openid = kwargs.get('openid')

        if email is not None:
            try:
                account = EmailAddress.objects.get(email=email).account
            except EmailAddress.DoesNotExist:
                raise CommandError("Email '%s' does not exist" % email)
        elif openid is not None:
            try:
                account = Account.objects.get(openid_identifier=openid)
            except Account.DoesNotExist:
                raise CommandError(
                    "Account with openid '%s' does not exist" % openid)
        else:
            raise CommandError("Need to specify --email or --openid")

        for team in args:
            add_user_to_team(account, team, create_team=False)
