from __future__ import absolute_import

import re

from honeypot.middleware import (
    HoneypotResponseMiddleware,
    HoneypotViewMiddleware,
)

HONEYPOT_EXEMPT_URLS = re.compile(
    '^/api/|^/[A-Za-z_]+/\+openid|^/\+openid|^/\+saml|^/saml')


class HoneypotMiddleware(HoneypotViewMiddleware, HoneypotResponseMiddleware):
    """Middleware that verifies a valid honeypot on all POSTs.

    Excluded are AJAX's requests and API requests.

    """

    def process_view(self, request, *args, **kwargs):
        response = None
        if not HONEYPOT_EXEMPT_URLS.match(request.path):
            # Only validate honeypot fields for requests that are not going
            # to our API endpoints.
            response = super(HoneypotMiddleware, self).process_view(
                request, *args, **kwargs)

        return response
