# Copyright 2010 Canonical Ltd.  This software is licensed under the
# GNU Affero General Public License version 3 (see the file LICENSE).

from urlparse import urlparse

from openid.yadis.accept import getAcceptable
from openid.yadis.constants import YADIS_CONTENT_TYPE, YADIS_HEADER_NAME

from django.core.urlresolvers import resolve, reverse
from django.http import Http404, HttpResponse
from django.shortcuts import get_object_or_404
from django.template.loader import render_to_string

from identityprovider.models import Account
from identityprovider.utils import get_provider_url


class XRDSMiddleware(object):

    def process_request(self, request):
        accept_content = request.META.get('HTTP_ACCEPT', '')
        # getAcceptable guarantees that only two values can be in acceptable
        acceptable = getAcceptable(accept_content,
                                   ['text/html', YADIS_CONTENT_TYPE])
        # Return the XRDS document if it is preferred to text/html.
        provider_url = get_provider_url(request)
        for mtype in acceptable:
            if mtype == 'text/html':
                break
            elif mtype == YADIS_CONTENT_TYPE:
                if request.get_full_path().startswith('/+id'):
                    # Special ID response
                    view, args, kwargs = resolve(
                        urlparse(request.get_full_path())[2])
                    account = get_object_or_404(
                        Account, openid_identifier=kwargs['identifier'])
                    if not account.is_active:
                        raise Http404
                    openid_identity_url = request.build_absolute_uri(
                        account.get_absolute_url())
                    context = {
                        'provider_url': provider_url,
                        'identity_url': openid_identity_url,
                    }
                    return self.xrds_response(
                        provider_url,
                        template='server/person-xrds.xml',
                        context=context)
                else:
                    # Default discovery response
                    extra_headers = {
                        YADIS_HEADER_NAME: request.build_absolute_uri(
                            reverse('server-xrds-discovery')),
                    }
                    return self.xrds_response(provider_url,
                                              extra_headers=extra_headers)
        return None

    def xrds_response(self, provider_url, template=None, context=None,
                      extra_headers=None):
        if template is None:
            template = 'server/openidapplication-xrds.xml'
        if context is None:
            context = {
                'endpoint_url': provider_url,
            }
        if extra_headers is None:
            extra_headers = {}
        response = HttpResponse(render_to_string(template, context))
        response['Content-type'] = YADIS_CONTENT_TYPE
        for header in extra_headers:
            response[header] = extra_headers[header]
        return response
