# -*- coding: utf-8 -*-
from __future__ import unicode_literals

import os

import django.utils.timezone
import django.core.validators

from django.conf import settings
from django.db import models, migrations

import identityprovider.utils
import identityprovider.models.account


def get_custom_sql():
    sql_folder = os.path.join(
        settings.BASE_DIR, 'src', 'identityprovider', 'sql')
    sql_content = []
    for i in os.listdir(sql_folder):
        if not i.endswith('.sql'):
            continue
        with open(os.path.join(sql_folder, i)) as f:
            sql_content.append(f.read())

    result = '\n'.join(sql_content)
    return result


class Migration(migrations.Migration):

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Account',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('date_created', models.DateTimeField(default=django.utils.timezone.now, editable=False)),
                ('creation_rationale', models.IntegerField(choices=[(1, b'UNKNOWN'), (2, b'BUGIMPORT'), (3, b'SOURCEPACKAGEIMPORT'), (4, b'POFILEIMPORT'), (5, b'KEYRINGTRUSTANALYZER'), (6, b'FROMEMAILMESSAGE'), (7, b'SOURCEPACKAGEUPLOAD'), (8, b'OWNER_CREATED_LAUNCHPAD'), (9, b'OWNER_CREATED_SHIPIT'), (10, b'OWNER_CREATED_UBUNTU_WIKI'), (11, b'USER_CREATED'), (12, b'OWNER_CREATED_UBUNTU_SHOP'), (13, b'OWNER_CREATED_UNKNOWN_TRUSTROOT'), (14, b'OWNER_SUBMITTED_HARDWARE_TEST'), (15, b'BUGWATCH'), (16, b'API_CREATED')])),
                ('creation_source', models.TextField(null=True, blank=True)),
                ('status', models.IntegerField(choices=[(10, 'Not activated'), (20, 'Active'), (30, 'Deactivated (by user)'), (40, 'Suspended (by admin)'), (50, 'Account deleted')])),
                ('date_status_set', models.DateTimeField(default=django.utils.timezone.now)),
                ('displayname', identityprovider.models.account.DisplaynameField()),
                ('openid_identifier', models.TextField(default=identityprovider.utils.generate_openid_identifier, unique=True)),
                ('oauth_secret', models.TextField(default=identityprovider.utils.generate_random_string_len_50, unique=True, null=True)),
                ('status_comment', models.TextField(null=True, blank=True)),
                ('old_openid_identifier', models.TextField(db_index=True, null=True, blank=True)),
                ('preferredlanguage', models.TextField(null=True, blank=True)),
                ('twofactor_required', models.BooleanField(default=False)),
                ('twofactor_attempts', models.SmallIntegerField(default=0)),
                ('warn_about_backup_device', models.BooleanField(default=True)),
                ('need_password_reset', models.NullBooleanField()),
            ],
            options={
                'db_table': 'account',
                'verbose_name': 'account',
                'verbose_name_plural': 'accounts',
                'permissions': (
                    ('api_view_account_details', 'Can view account details through API calls'),
                    ('api_edit_account_details', 'Can edit account details through API calls'),
                ),
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='AccountPassword',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('password', identityprovider.models.account.PasswordField()),
                ('account', models.OneToOneField(db_column=b'account', to='identityprovider.Account')),
            ],
            options={
                'db_table': 'accountpassword',
                'verbose_name': 'account password',
                'verbose_name_plural': 'account passwords',
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='APIUser',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('username', models.CharField(max_length=256)),
                ('password', models.CharField(max_length=256, editable=False)),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
            ],
            options={
                'db_table': 'api_user',
                'verbose_name': 'API user',
                'verbose_name_plural': 'API users',
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='AuthenticationDevice',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('key', models.TextField()),
                ('name', models.TextField()),
                ('counter', models.IntegerField(default=0)),
                ('device_type', models.TextField(null=True)),
                ('account', models.ForeignKey(related_name='devices', to='identityprovider.Account')),
            ],
            options={
                'ordering': ('id',),
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='AuthToken',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('date_created', models.DateTimeField(default=django.utils.timezone.now, db_index=True, editable=False, blank=True)),
                ('date_consumed', models.DateTimeField(db_index=True, null=True, blank=True)),
                ('token_type', models.IntegerField(choices=[(1, b'PASSWORDRECOVERY'), (2, b'ACCOUNTMERGE'), (3, b'NEWACCOUNT'), (4, b'VALIDATEEMAIL'), (5, b'VALIDATETEAMEMAIL'), (6, b'VALIDATEGPG'), (7, b'VALIDATESIGNONLYGPG'), (8, b'PROFILECLAIM'), (9, b'NEWPROFILE'), (10, b'TEAMCLAIM'), (11, b'BUGTRACKER'), (12, b'NEWPERSONLESSACCOUNT'), (13, b'INVALIDATEEMAIL')])),
                ('token', models.TextField(unique=True)),
                ('requester_email', models.TextField(null=True, blank=True)),
                ('email', models.TextField(db_index=True, validators=[django.core.validators.EmailValidator()])),
                ('redirection_url', models.TextField(null=True, blank=True)),
                ('displayname', identityprovider.models.account.DisplaynameField(null=True, blank=True)),
                ('password', identityprovider.models.account.PasswordField(null=True, blank=True)),
                ('requester', models.ForeignKey(db_column=b'requester', blank=True, to='identityprovider.Account', null=True)),
            ],
            options={
                'db_table': 'authtoken',
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='EmailAddress',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('email', models.TextField(validators=[django.core.validators.EmailValidator()])),
                ('lp_person', models.IntegerField(null=True, editable=False, db_column=b'person', blank=True)),
                ('status', models.IntegerField(choices=[(1, b'NEW'), (2, b'VALIDATED'), (4, b'PREFERRED')])),
                ('date_created', models.DateTimeField(default=django.utils.timezone.now, editable=False, blank=True)),
                ('account', models.ForeignKey(db_column=b'account', blank=True, to='identityprovider.Account', null=True)),
            ],
            options={
                'db_table': 'emailaddress',
                'verbose_name_plural': 'Email addresses',
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='InvalidatedEmailAddress',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('email', models.TextField(validators=[django.core.validators.EmailValidator()])),
                ('date_created', models.DateTimeField(editable=False, blank=True)),
                ('date_invalidated', models.DateTimeField(default=django.utils.timezone.now, null=True, blank=True)),
                ('account_notified', models.BooleanField(default=False)),
                ('account', models.ForeignKey(db_column=b'account', blank=True, to='identityprovider.Account', null=True)),
            ],
            options={
                'db_table': 'invalidated_emailaddress',
                'verbose_name_plural': 'Invalidated email addresses',
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='LeakedCredential',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('email', models.EmailField(default=None, max_length=254)),
                ('password', models.TextField(default=None)),
                ('source', models.TextField(default=None)),
                ('when_leaked', models.DateField(default=None)),
                ('when_created', models.DateTimeField(default=django.utils.timezone.now)),
            ],
            options={
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='LPOpenIdIdentifier',
            fields=[
                ('identifier', models.TextField(unique=True, serialize=False, primary_key=True)),
                ('lp_account', models.IntegerField(db_column=b'account', db_index=True)),
                ('date_created', models.DateTimeField(default=django.utils.timezone.now)),
            ],
            options={
                'db_table': 'lp_openididentifier',
                'verbose_name': 'LP OpenID Identifier',
                'verbose_name_plural': 'LP OpenID Identifiers',
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='OpenIDAssociation',
            fields=[
                ('server_url', models.CharField(max_length=2047)),
                ('handle', models.CharField(max_length=255, serialize=False, primary_key=True)),
                ('secret', models.TextField()),
                ('issued', models.IntegerField()),
                ('lifetime', models.IntegerField()),
                ('assoc_type', models.CharField(max_length=64)),
            ],
            options={
                'db_table': 'openidassociation',
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='OpenIDAuthorization',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('client_id', models.TextField(null=True, blank=True)),
                ('date_created', models.DateTimeField(default=django.utils.timezone.now, editable=False, blank=True)),
                ('date_expires', models.DateTimeField()),
                ('trust_root', models.TextField()),
                ('account', models.ForeignKey(to='identityprovider.Account', db_column=b'account')),
            ],
            options={
                'db_table': 'openidauthorization',
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='OpenIDNonce',
            fields=[
                ('server_url', models.CharField(max_length=2047, serialize=False, primary_key=True)),
                ('timestamp', models.IntegerField()),
                ('salt', models.CharField(max_length=40)),
            ],
            options={
                'db_table': 'openidnonce',
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='OpenIDRPConfig',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('trust_root', models.TextField(unique=True)),
                ('displayname', models.TextField()),
                ('description', models.TextField()),
                ('logo', models.TextField(null=True, blank=True)),
                ('allowed_user_attribs', models.TextField(null=True, blank=True)),
                ('allowed_ax', models.TextField(null=True, blank=True)),
                ('allowed_sreg', models.TextField(null=True, blank=True)),
                ('creation_rationale', models.IntegerField(default=13, choices=[(1, b'UNKNOWN'), (2, b'BUGIMPORT'), (3, b'SOURCEPACKAGEIMPORT'), (4, b'POFILEIMPORT'), (5, b'KEYRINGTRUSTANALYZER'), (6, b'FROMEMAILMESSAGE'), (7, b'SOURCEPACKAGEUPLOAD'), (8, b'OWNER_CREATED_LAUNCHPAD'), (9, b'OWNER_CREATED_SHIPIT'), (10, b'OWNER_CREATED_UBUNTU_WIKI'), (11, b'USER_CREATED'), (12, b'OWNER_CREATED_UBUNTU_SHOP'), (13, b'OWNER_CREATED_UNKNOWN_TRUSTROOT'), (14, b'OWNER_SUBMITTED_HARDWARE_TEST'), (15, b'BUGWATCH'), (16, b'API_CREATED')])),
                ('can_query_any_team', models.BooleanField(default=False)),
                ('auto_authorize', models.BooleanField(default=False)),
                ('require_two_factor', models.BooleanField(default=False)),
                ('ga_snippet', models.TextField(null=True, blank=True)),
                ('prefer_canonical_email', models.BooleanField(default=False)),
                ('allow_unverified', models.BooleanField(default=False)),
                ('flag_twofactor', models.CharField(max_length=256, null=True, blank=True)),
            ],
            options={
                'db_table': 'ssoopenidrpconfig',
                'verbose_name': 'OpenID RP Config',
                'verbose_name_plural': 'OpenID RP Configs',
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='OpenIDRPSummary',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('openid_identifier', models.TextField(db_index=True)),
                ('trust_root', models.TextField(db_index=True)),
                ('date_created', models.DateTimeField(default=django.utils.timezone.now, editable=False, blank=True)),
                ('date_last_used', models.DateTimeField(default=django.utils.timezone.now, editable=False, blank=True)),
                ('total_logins', models.IntegerField(default=1)),
                ('approved_data', models.TextField(default='', null=True, blank=True)),
                ('account', models.ForeignKey(to='identityprovider.Account', db_column=b'account')),
            ],
            options={
                'db_table': 'openidrpsummary',
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='Person',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('displayname', models.TextField(null=True, blank=True)),
                ('teamowner', models.IntegerField(null=True, db_column=b'teamowner', blank=True)),
                ('teamdescription', models.TextField(null=True, blank=True)),
                ('name', models.TextField(unique=True, null=True)),
                ('language', models.IntegerField(null=True, db_column=b'language', blank=True)),
                ('fti', models.TextField(null=True)),
                ('defaultmembershipperiod', models.IntegerField(null=True, blank=True)),
                ('defaultrenewalperiod', models.IntegerField(null=True, blank=True)),
                ('subscriptionpolicy', models.IntegerField(default=1, null=True)),
                ('merged', models.IntegerField(null=True, db_column=b'merged', blank=True)),
                ('datecreated', models.DateTimeField(auto_now_add=True, null=True)),
                ('addressline1', models.TextField(null=True, blank=True)),
                ('addressline2', models.TextField(null=True, blank=True)),
                ('organization', models.TextField(null=True, blank=True)),
                ('city', models.TextField(null=True, blank=True)),
                ('province', models.TextField(null=True, blank=True)),
                ('country', models.IntegerField(null=True, db_column=b'country', blank=True)),
                ('postcode', models.TextField(null=True, blank=True)),
                ('phone', models.TextField(null=True, blank=True)),
                ('homepage_content', models.TextField(null=True, blank=True)),
                ('icon', models.IntegerField(null=True, db_column=b'icon', blank=True)),
                ('mugshot', models.IntegerField(null=True, db_column=b'mugshot', blank=True)),
                ('hide_email_addresses', models.NullBooleanField(default=False)),
                ('creation_rationale', models.IntegerField(blank=True, null=True, choices=[(1, b'UNKNOWN'), (2, b'BUGIMPORT'), (3, b'SOURCEPACKAGEIMPORT'), (4, b'POFILEIMPORT'), (5, b'KEYRINGTRUSTANALYZER'), (6, b'FROMEMAILMESSAGE'), (7, b'SOURCEPACKAGEUPLOAD'), (8, b'OWNER_CREATED_LAUNCHPAD'), (9, b'OWNER_CREATED_SHIPIT'), (10, b'OWNER_CREATED_UBUNTU_WIKI'), (11, b'USER_CREATED'), (12, b'OWNER_CREATED_UBUNTU_SHOP'), (13, b'OWNER_CREATED_UNKNOWN_TRUSTROOT'), (14, b'OWNER_SUBMITTED_HARDWARE_TEST'), (15, b'BUGWATCH'), (16, b'API_CREATED')])),
                ('creation_comment', models.TextField(null=True, blank=True)),
                ('registrant', models.IntegerField(null=True, db_column=b'registrant', blank=True)),
                ('logo', models.IntegerField(null=True, db_column=b'logo', blank=True)),
                ('renewal_policy', models.IntegerField(default=10, null=True)),
                ('personal_standing', models.IntegerField(default=0, null=True)),
                ('personal_standing_reason', models.TextField(null=True, blank=True)),
                ('mail_resumption_date', models.DateField(null=True, blank=True)),
                ('mailing_list_auto_subscribe_policy', models.IntegerField(default=1, null=True)),
                ('mailing_list_receive_duplicates', models.NullBooleanField(default=True)),
                ('visibility', models.IntegerField(default=1, null=True)),
                ('verbose_bugnotifications', models.NullBooleanField(default=False)),
                ('lp_account', models.IntegerField(unique=True, null=True, db_column=b'account')),
            ],
            options={
                'db_table': 'lp_person',
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='PersonLocation',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('date_created', models.DateTimeField(null=True)),
                ('latitude', models.FloatField(null=True, blank=True)),
                ('longitude', models.FloatField(null=True, blank=True)),
                ('time_zone', models.TextField(null=True, blank=True)),
                ('last_modified_by', models.IntegerField(null=True, db_column=b'last_modified_by')),
                ('date_last_modified', models.DateTimeField(null=True)),
                ('visible', models.NullBooleanField(default=True)),
                ('locked', models.NullBooleanField(default=False)),
                ('person', models.OneToOneField(null=True, db_column=b'person', to='identityprovider.Person')),
            ],
            options={
                'db_table': 'lp_personlocation',
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='TeamParticipation',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('person', models.ForeignKey(db_column=b'person', to='identityprovider.Person', null=True)),
                ('team', models.ForeignKey(related_name='team_participations', db_column=b'team', to='identityprovider.Person', null=True)),
            ],
            options={
                'db_table': 'lp_teamparticipation',
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='Token',
            fields=[
                ('name', models.TextField()),
                ('scope', models.TextField(default='api-v2', choices=[('api-v2', b'VERSION_2'), ('web', b'WEB_LOGIN')])),
                ('key', models.TextField(default=identityprovider.utils.generate_random_string_len_60, serialize=False, primary_key=True)),
                ('secret', models.TextField(default=identityprovider.utils.generate_random_string_len_70)),
                ('date_created', models.DateTimeField(default=django.utils.timezone.now)),
                ('date_updated', models.DateTimeField(default=django.utils.timezone.now)),
                ('consumer', models.ForeignKey(to='identityprovider.Account')),
            ],
            options={
            },
            bases=(models.Model,),
        ),
        migrations.AlterUniqueTogether(
            name='token',
            unique_together=set([('consumer', 'name')]),
        ),
        migrations.AlterUniqueTogether(
            name='teamparticipation',
            unique_together=set([('team', 'person')]),
        ),
        migrations.AlterUniqueTogether(
            name='openidrpsummary',
            unique_together=set([('account', 'trust_root', 'openid_identifier')]),
        ),
        migrations.AlterUniqueTogether(
            name='openidnonce',
            unique_together=set([('server_url', 'timestamp', 'salt')]),
        ),
        migrations.AlterUniqueTogether(
            name='openidassociation',
            unique_together=set([('server_url', 'handle')]),
        ),
        migrations.AlterUniqueTogether(
            name='leakedcredential',
            unique_together=set([('email', 'source')]),
        ),
        migrations.RunSQL(get_custom_sql()),
    ]
