# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations
import django.utils.timezone

# Indexes created manually because Django's automatic indexes or
# index_together can't handle DESC indexes or upper().
# Data type for primary key altered because Django's AutoField is
# created as integer by default and can't be overridden.
# Note that just trying to define id = BigIntegerField(primary_key=True)
# does not work as expected, because it still lacks the auto-increment
# functionality which primary keys require and is implemented in AutoField.
SQL = ("CREATE INDEX identityprovider_authlog_account_when_created "
       "ON identityprovider_authlog (account_id, when_created desc) "
       "WHERE account_id IS NOT NULL;"
       "CREATE INDEX identityprovider_authlog_login_email_when_created "
       "ON identityprovider_authlog (upper(login_email), when_created desc);"
       "ALTER TABLE identityprovider_authlog ALTER COLUMN id TYPE bigint;")
REVERSE_SQL = ("DROP INDEX identityprovider_authlog_account_when_created;"
               "DROP INDEX identityprovider_authlog_login_email_when_created;")


class Migration(migrations.Migration):

    dependencies = [
        ('identityprovider', '0004_accountpassword_last_leak_check'),
    ]

    operations = [
        migrations.CreateModel(
            name='AuthLog',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('log_type', models.IntegerField(choices=[(1, b'OPENID_FAIL'), (2, b'OPENID_NEW'), (3, b'OPENID_EXISTING'), (4, b'API_FAIL'), (5, b'API_NEW'), (6, b'API_EXISTING')])),
                ('when_created', models.DateTimeField(default=django.utils.timezone.now)),
                ('login_email', models.TextField(default='')),
                ('referer', models.TextField()),
                ('remote_ip', models.GenericIPAddressField()),
                ('user_agent', models.TextField()),
                ('account', models.ForeignKey(to='identityprovider.Account', null=True)),
            ],
            options={
            },
            bases=(models.Model,),
        ),
        migrations.RunSQL(SQL, reverse_sql=REVERSE_SQL),
    ]
