# Copyright 2010 Canonical Ltd.  This software is licensed under the
# GNU Affero General Public License version 3 (see the file LICENSE).

from __future__ import unicode_literals

from django.contrib.auth.models import (
    check_password,
    is_password_usable,
    make_password,
)
from django.db import models
from django.utils.translation import ugettext_lazy as _

from identityprovider.utils import validate_launchpad_password


class APIUser(models.Model):
    username = models.CharField(max_length=256)
    password = models.CharField(max_length=256, editable=False)

    created_at = models.DateTimeField(auto_now_add=True)
    updated_at = models.DateTimeField(auto_now=True)

    def set_password(self, password, salt=None):
        self.password = make_password(password, salt=salt)

    def _verify_password(self, password):
        """Protected verification method.

        Please note that it saves the APIUser instance if it has to change the
        password cypher in use, as long as we still have instances with the old
        Launchpad cypher."""
        if is_password_usable(self.password):
            return check_password(password, self.password)
        elif validate_launchpad_password(password, self.password):
            self.password = make_password(password)
            self.save()
            return True
        return False

    @classmethod
    def authenticate(cls, username, password):
        try:
            api_user = cls.objects.get(username=username)
            if api_user._verify_password(password):
                return api_user
        except cls.DoesNotExist:
            pass
        return None

    def is_authenticated(self):
        # behave like django.contrib.auth.models.User
        return True

    class Meta:
        app_label = "identityprovider"
        db_table = "api_user"
        verbose_name = _('API user')
        verbose_name_plural = _('API users')

    def __unicode__(self):
        return self.username
