# Copyright 2015 Canonical Ltd.  This software is licensed under
# the GNU Affero General Public License version 3 (see the file
# LICENSE).

from __future__ import unicode_literals

from django.db import models
from django.utils.timezone import now

from identityprovider.models import Account
from identityprovider.models.const import AuthLogType

__all__ = (
    'AuthLog',
)


class AuthLog(models.Model):

    log_type = models.IntegerField(choices=AuthLogType._get_choices())
    when_created = models.DateTimeField(default=now)
    # login_email should be logged raw so it's a TextField rather than
    # EmailField, so we can 1) accept input longer than 255 chars, and 2)
    # accept input that's not valid e-mail addresses (we want to log that).
    login_email = models.TextField(default='', null=False)
    account = models.ForeignKey(Account, null=True)
    referer = models.TextField()
    remote_ip = models.GenericIPAddressField()
    user_agent = models.TextField()

    class Meta:
        app_label = 'identityprovider'

    def __unicode__(self):
        if self.account:
            who = self.account
        else:
            who = self.login_email
        return u"%s: %s (%s)" % (
            self.get_log_type_display(), who, self.remote_ip)

    def log_type_label(self):
        return AuthLogType._label_for(self.log_type)
