from django.db.backends.dummy.base import (
    DatabaseWrapper as BaseDatabaseWrapper,
    ignore,
)

__all__ = [
    'DatabaseWrapper',
]

try:
    import psycopg2 as Database
except ImportError as e:
    from django.core.exceptions import ImproperlyConfigured
    raise ImproperlyConfigured("Error loading psycopg2 module: %s" % e)


class NopConnection(object):
    """DB connection which does nothing."""


class NopCursorWrapper(object):
    """This cursor wrappper ignores any operations used on it."""
    execute = ignore
    executemany = ignore
    callproc = ignore
    fetchone = ignore
    rowcount = 0
    lastrowid = None

    def fetchmany(self, *args):
        return []

    def fetchall(self):
        return []

    def close(self):
        pass

    def __enter__(self, *a, **kw):
        return self

    def __exit__(self, *a, **kw):
        pass


class DatabaseWrapper(BaseDatabaseWrapper):
    """Backend which ignores any SQL sent to it."""

    Database = Database

    # define a valid set of operators
    operators = {
        'exact': '= %s',
        'iexact': '= UPPER(%s)',
        'contains': 'LIKE %s',
        'icontains': 'LIKE UPPER(%s)',
        'regex': '~ %s',
        'iregex': '~* %s',
        'gt': '> %s',
        'gte': '>= %s',
        'lt': '< %s',
        'lte': '<= %s',
        'startswith': 'LIKE %s',
        'endswith': 'LIKE %s',
        'istartswith': 'LIKE UPPER(%s)',
        'iendswith': 'LIKE UPPER(%s)',
    }

    # Override the base class implementations with null
    # implementations.
    _commit = ignore
    ensure_connection = ignore
    enter_transaction_management = ignore
    set_clean = ignore
    savepoint_commit = ignore

    def __init__(self, *args, **kwargs):
        super(DatabaseWrapper, self).__init__(*args, **kwargs)

        self.features.supports_transactions = False
        self.ops.quote_name = lambda x: x

    def cursor(self):
        return NopCursorWrapper()

    def get_connection_params(self):
        return {}

    def get_new_connection(self, conn_params):
        return NopConnection()

    def init_connection_state(self):
        return

    def _set_autocommit(self, autocommit):
        return
