import oops
import oops_dictconfig
import oops_timeline
import oops_wsgi
import timeline_django.filters
from django.conf import settings

from identityprovider import timeline_filters


def install_timeline_hooks(config):
    oops_timeline.install_hooks(config)
    timeline_django.filters.install_hooks(config)
    timeline_filters.install_hooks(config)


class ErrorReporter(object):

    def __init__(self):
        # Ensure there is always a config
        self.oops_config = oops.Config()

    def setup(self):
        config = oops_dictconfig.config_from_dict(settings.OOPSES)
        oops_wsgi.install_hooks(config)
        install_timeline_hooks(config)
        self.oops_config = config
        return self.oops_config

    def make_context(self, exc_info=None, environ=None, request=None):
        if not environ and request:
            environ = getattr(request, 'environ', {})
        context = dict(exc_info=exc_info, wsgi_environ=environ)
        if environ:
            context.update(environ.get('oops.context', {}))
            if 'timeline.timeline' in environ:
                context['timeline'] = environ['timeline.timeline']
        if request:
            context['url'] = request.build_absolute_uri()
        return context

    def trigger_oops(self, exc_info=None, environ=None, request=None):
        context = self.make_context(exc_info=exc_info, environ=environ,
                                    request=request)
        report = self.oops_config.create(context=context)
        ids = self.oops_config.publish(report)
        return ids


global_error_reporter = ErrorReporter()


class ManuallyGeneratedOops(Exception):
    pass
