from django.test import SimpleTestCase

from identityprovider.nop_backend.base import (
    NopCursorWrapper,
    DatabaseWrapper,
)
from identityprovider.models import Account


class NopCursorWrapperTestCase(SimpleTestCase):

    def setUp(self):
        super(NopCursorWrapperTestCase, self).setUp()
        self.wrapper = NopCursorWrapper()

    def test_ignored_methods(self):
        self.assertIsNone(self.wrapper.execute('SELECT 42'))
        self.assertIsNone(self.wrapper.executemany('SECECT 42', [1, 2]))
        self.assertIsNone(self.wrapper.callproc('STORED()'))

    def test_fetchone(self):
        self.assertIsNone(self.wrapper.fetchone())

    def test_fetchmany(self):
        self.assertEqual(self.wrapper.fetchmany(10), [])

    def test_fetchall(self):
        self.assertEqual(self.wrapper.fetchall(), [])


class DatabaseWrapperTestCase(SimpleTestCase):

    def test_cursor_returns_correct_instance(self):
        dbwrapper = DatabaseWrapper({})
        cursor = dbwrapper.cursor()

        self.assertTrue(isinstance(cursor, NopCursorWrapper))

    def _test_operator(self, operator):
        with self.assertRaises(Account.DoesNotExist):
            key = 'openid_identifier__%s' % operator
            kwargs = {key: 'invalid'}
            Account.objects.using('nop').get(**kwargs)

    def test_orm_iexact(self):
        self._test_operator('iexact')

    def test_orm_contains(self):
        self._test_operator('contains')

    def test_orm_icontains(self):
        self._test_operator('icontains')

    def test_orm_regex(self):
        self._test_operator('regex')

    def test_orm_iregex(self):
        self._test_operator('iregex')

    def test_orm_gt(self):
        self._test_operator('gt')

    def test_orm_gte(self):
        self._test_operator('gte')

    def test_orm_lt(self):
        self._test_operator('lt')

    def test_orm_lte(self):
        self._test_operator('lte')

    def test_orm_startswith(self):
        self._test_operator('startswith')

    def test_orm_endswith(self):
        self._test_operator('endswith')

    def test_orm_istartswith(self):
        self._test_operator('istartswith')

    def test_orm_iendswith(self):
        self._test_operator('iendswith')

    def test_orm_update(self):
        Account.objects.using('nop').update(
            openid_identifier='invalid')

    def test_orm_create(self):
        Account.objects.using('nop').create(
            openid_identifier='invalid')
