from django.apps import AppConfig
from django.core.checks import Warning
from django.test import TestCase, override_settings

from identityprovider.checks import gpgservice_endpoint_check


class CheckTests(TestCase):

    @override_settings(GPGSERVICE_ENDPOINT=None)
    def test_gpgservice_endpoint_check_unset(self):
        warnings = gpgservice_endpoint_check(AppConfig)
        msg = ('GPGSERVICE_ENDPOINT must be set for key management '
               'functionality.')
        hint = 'Set GPGSERVICE_ENDPOINT in ../local_config/settings.py'
        expected_warnings = [
            Warning(msg, hint=hint, id='identityprovider.W001')]
        self.assertEqual(warnings, expected_warnings)

    @override_settings(GPGSERVICE_ENDPOINT='http://gpgservice')
    def test_gpgservice_endpoint_check_set(self):
        warnings = gpgservice_endpoint_check(AppConfig)
        self.assertEqual(0, len(warnings))
