# Copyright 2016 Canonical Ltd.  This software is licensed under the
# GNU Affero General Public License version 3 (see the file LICENSE).


from identityprovider.tests.utils import SSOBaseTestCase

from webui.gpg import (
    get_user_id_for_account,
    SSOGPGClient,
)
from webui.tests.gpg_fixture import SSOGPGServiceFixture


class AddGPGKeyTestCase(SSOBaseTestCase):

    def setUp(self):
        super(AddGPGKeyTestCase, self).setUp()
        self.account = self.factory.make_account()

    def test_raises_runtimeerror_when_service_fixture_not_present(self):
        self.assertRaises(
            RuntimeError,
            self.factory.add_gpgkey_to_account,
            self.account
        )

    def test_raises_ValueError_on_bad_fingerprint(self):
        self.use_fixture(SSOGPGServiceFixture())
        self.assertRaises(
            ValueError,
            self.factory.add_gpgkey_to_account,
            self.account,
            "This aint no fingerprint!"
        )

    def test_raises_ValueError_on_bad_algorithm(self):
        self.use_fixture(SSOGPGServiceFixture())
        self.assertRaises(
            ValueError,
            self.factory.add_gpgkey_to_account,
            self.account,
            algorithm='t'
        )

    def test_returns_valid_fingerprint(self):
        self.use_fixture(SSOGPGServiceFixture())
        fingerprint = self.factory.add_gpgkey_to_account(self.account)
        self.assertEqual(40, len(fingerprint))

    def test_key_can_be_retrieved(self):
        self.use_fixture(SSOGPGServiceFixture())
        fingerprint = self.factory.add_gpgkey_to_account(self.account)
        client = SSOGPGClient()
        user_id = get_user_id_for_account(self.account)
        keys = client.getKeysForOwner(user_id)['keys']

        self.assertEqual(1, len(keys))
        self.assertEqual(keys[0]['fingerprint'], fingerprint)
