import bson
import os
import shutil

from django.conf import settings

from mock import Mock

from identityprovider.tests.utils import SSOBaseTestCase
from u1testutils.wsgi_intercept import WSGIInterceptedTestCase

from identityprovider.wsgi import make_app, BzrRevnoMiddleware


class WsgiTestCase(SSOBaseTestCase, WSGIInterceptedTestCase):

    def setUp(self):
        super(WsgiTestCase, self).setUp()
        self.environ = {
            'PATH_INFO': '/',
            'QUERY_STRING': '',
            'REMOTE_ADDR': '127.0.0.1',
            'REQUEST_METHOD': 'GET',
            'SCRIPT_NAME': '',
            'SERVER_NAME': 'testserver',
            'SERVER_PORT': '80',
            'SERVER_PROTOCOL': 'HTTP/1.1',
            'wsgi.version': (1, 0),
            'wsgi.url_scheme': 'http',
            'wsgi.multiprocess': True,
            'wsgi.multithread': False,
            'wsgi.run_once': False,
            'wsgi.input': '',
        }
        self.start_response = Mock()

        self.oops_dir = settings.OOPSES['publishers'][0]['error_dir']
        self.addCleanup(shutil.rmtree, self.oops_dir, ignore_errors=True)

    def read_oops_from_disk(self):
        # Helper to read in the oops written to disk.
        # There is only one date directory in the oops directory.
        dated_dirs = os.listdir(self.oops_dir)
        self.assertEqual(1, len(dated_dirs))

        # There is only one oops.
        todays_oops_path = dated_dirs[0]
        oops_list = os.listdir(self.oops_dir + '/' + todays_oops_path)
        self.assertEqual(
            1, len(oops_list), 'Too many oopses in folder %s' % self.oops_dir)

        oops_path = self.oops_dir + '/' + todays_oops_path + '/' + oops_list[0]
        with open(oops_path, "r") as oops_file:
            oops_file_contents = oops_file.read()
        return bson.loads(oops_file_contents)

    def request_wsgi_response(self, environ):
        app = make_app()
        response = app(environ, self.start_response).next()
        return response

    def test_oopsplease(self):
        make_app()

        self.client.get('/', data=dict(oopsplease=True))

        oops = self.read_oops_from_disk()
        self.assertEqual(oops['type'], 'ManuallyGeneratedOops')

    def test_bzr_header(self):
        BzrRevnoMiddleware.REVNO_HEADER = ('HEADER', 'VALUE')
        self.request_wsgi_response(self.environ)
        start_response_args = self.start_response.mock_calls[0][1]
        headers = start_response_args[1]
        self.assertIn(('HEADER', 'VALUE'), headers)
