# Copyright 2010 Canonical Ltd.  This software is licensed under the
# GNU Affero General Public License version 3 (see the file LICENSE).

import json
import logging

from django.conf import settings
from django.contrib.admin.views.decorators import staff_member_required
from django.http import HttpResponse, HttpResponseRedirect, Http404
from django.shortcuts import render
from django.views.decorators.csrf import csrf_exempt
from django.views.decorators.http import require_POST

from identityprovider.readonly import (
    ReadOnlyManager,
    get_server_atts,
    update_server,
)


logger = logging.getLogger(__name__)


@staff_member_required
def readonly_admin(request):
    atts = get_server_atts(settings.APP_SERVERS)
    return render(request, 'admin/readonly.html', atts)


@staff_member_required
def readonly_confirm(request, action, appserver=None):
    if request.method == 'POST':
        update_server(action, appserver)
        return HttpResponseRedirect('/readonly')
    context = {
        'appserver': appserver,
        'action': action,
    }
    return render(request, 'admin/readonly_confirm.html', context)


@csrf_exempt
@require_POST
def readonly_data(request):
    """Provides data about the readonly status of this app server."""

    secret = request.POST.get('secret')
    if secret != settings.READONLY_SECRET:
        logger.warning(
            'readonly_data request received with incorrect secret %r', secret)
        raise Http404()

    action = request.POST.get('action')
    romanager = ReadOnlyManager()

    if action == 'set':
        romanager.set_readonly()
    elif action == 'clear':
        romanager.clear_readonly()

    result = {
        'readonly': settings.READ_ONLY_MODE,
    }
    return HttpResponse(json.dumps(result))
