# Copyright 2010 Canonical Ltd.  This software is licensed under the
# GNU Affero General Public License version 3 (see the file LICENSE).

from django.contrib.auth.models import User
from django.test import TestCase

from .models import Consumer, Token


class BaseTestCase(TestCase):

    i = 0

    def setUp(self):
        super(BaseTestCase, self).setUp()
        self.user = User.objects.create_user(
            'test_username', 'test@canonical.com', 'password')

    def make_consumer(self, user=None):
        if user is None:
            username = 'user-%i' % self.i
            self.i += 1
            user = User.objects.create_user(
                username, '%s@canonical.com' % username, 'password')

        return Consumer.objects.create(user=user)

    def make_token(
            self, consumer=None, token_key=None, token_secret=None, name=None):
        if consumer is None:
            consumer = self.make_consumer()
        if token_key is None:
            token_key = 'token_key-%i' % self.i
        if token_secret is None:
            token_secret = 'token_secret-%i' % self.i
        if name is None:
            name = 'name-%i' % self.i

        self.i += 1
        return Token.objects.create(
            consumer=consumer, token=token_key, token_secret=token_secret,
            name=name)


class TokenTestCase(BaseTestCase):

    def setUp(self):
        super(TokenTestCase, self).setUp()
        self.consumer = self.make_consumer()
        self.token = self.make_token(consumer=self.consumer, token_key='token')

    def test_unicode(self):
        self.assertEqual(unicode(self.token), u'token')

    def test_serialize(self):
        expected = {'consumer_key': self.consumer.key,
                    'consumer_secret': self.consumer.secret,
                    'token': self.token.token,
                    'token_secret': self.token.token_secret,
                    'name': self.token.name,
                    'created': str(self.token.created_at),
                    'updated': str(self.token.updated_at)}
        self.assertEqual(self.token.serialize(), expected)


class ConsumerTestCase(BaseTestCase):

    def test_unicode(self):
        consumer, _ = Consumer.objects.get_or_create(user=self.user)
        self.assertEqual(unicode(consumer),
                         unicode(self.user.username))

    def test_one_to_one_relationship_with_user(self):
        consumer, _ = Consumer.objects.get_or_create(user=self.user)

        self.assertEquals(self.user.id, consumer.user.id)
        self.assertEquals(consumer.id, self.user.oauth_consumer.id)
