# Copyright 2010 Canonical Ltd.  This software is licensed under the
# GNU Affero General Public License version 3 (see the file LICENSE).
import urllib2

from identityprovider.tests.utils import SSOBaseTestCase
from webservices.utils import http_request_with_timeout


class HttpRequestWithTimeoutTestCase(SSOBaseTestCase):

    def setUp(self):
        super(HttpRequestWithTimeoutTestCase, self).setUp()
        self.exception = None
        self.output = None
        self.headers = None

        class MockDatafile(object):

            def __init__(self, output, headers):
                self.output = output
                self.headers = headers

            def read(self):
                return self.output

            def info(self):
                return self.headers

        def mock_urlopen(request):
            self.request = request
            if self.exception:
                raise urllib2.URLError("arg")
            return MockDatafile(self.output, self.headers)

        self.patch(urllib2, 'urlopen', new=mock_urlopen)

    def test_without_data_and_successful_outcome(self):
        self.output = "output"
        response = http_request_with_timeout("http://example.com")
        self.assertEqual("output", response.read())

    def test_without_data_and_failing(self):
        self.exception = True
        self.assertRaises(
            urllib2.URLError,
            http_request_with_timeout, "http://example.com")

    def test_with_data_and_successful_outcome(self):
        self.output = "output"
        http_request_with_timeout("http://example.com",
                                  {"i1": "v1", "i2": "v2"})
        self.assertTrue("&" in self.request.data)
