from __future__ import unicode_literals

from django.core.urlresolvers import reverse

from identityprovider.models.account import Account
from identityprovider.tests.utils import SSOBaseTestCase
from identityprovider.tests import DEFAULT_USER_PASSWORD


class SetLanguageTestCase(SSOBaseTestCase):

    url = reverse('set_language')

    def setUp(self):
        super(SetLanguageTestCase, self).setUp()
        self.addCleanup(self.client.post, self.url, {'language': 'en'})

    def test_when_supplying_non_local_next_url_redirects_to_main(self):
        r = self.client.post(
            self.url, {'language': 'es', 'next': 'http://example.com'})
        self.assertRedirects(r, '/')

    def test_next_must_be_resolved_to_existing_view(self):
        r = self.client.post(
            self.url, {'language': 'es', 'next': '/not-existing'})
        self.assertRedirects(r, '/')

    def test_next_works_for_to_be_resolved_for_existing_view(self):
        self.preseed_cookie_check()
        r = self.client.post(
            self.url, {'language': 'es', 'next': '/+login'})
        self.assertRedirects(r, '/+login')

    def test_not_known_http_method(self):
        r = self.client.put(self.url)
        self.assertEqual(r.status_code, 405)

        r = self.client.delete(self.url)
        self.assertEqual(r.status_code, 405)

    def test_setting_unsupported_language_raises_404(self):
        r = self.client.post(self.url, {'language': 'xx'})
        self.assertEqual(r.status_code, 404)

    def test_getting_renders_choose_page(self):
        r = self.client.get(self.url)
        self.assertTemplateUsed(r, 'select_language.html')

    def test_setting_language_for_authenticated_users_updates_db(self):
        account = self.factory.make_account()
        self.client.login(username=account.preferredemail.email,
                          password=DEFAULT_USER_PASSWORD)
        self.client.post(self.url, {'language': 'es', 'next': '/'})

        account = Account.objects.get(id=account.id)

        self.assertEqual(account.preferredlanguage, 'es')
