# Copyright 2010, 2012 Canonical Ltd.  This software is licensed under
# the GNU Affero General Public License version 3 (see the file
# LICENSE).

from django.conf.urls import patterns, url

from identityprovider.models import AUTHTOKEN_PATTERN


repls = {
    'token': '(?P<token>[A-Za-z0-9]{16})',
    'authtoken': '(?P<authtoken>%s)' % AUTHTOKEN_PATTERN,
    'email_address': '(?P<email_address>.+)',
    'fingerprint': '(?P<fingerprint>.+)',
}

urlpatterns = patterns(
    'webui.views.ui',
    # Django's URL-reversing doesn't like to play with regex
    # alternates '|' or optionals '?'.  Named parameters in such
    # clauses get clobbered to such names as '_0'.  Breaking out the
    # combinations ourselves ensures the names are maintained.
    url(r'^\+login$', 'login_view', name='login'),
    url(r'^%(token)s/\+login$' % repls, 'login_view', name='login'),

    url(r'^\+logout$' % repls, 'logout', name='logout'),
    url(r'^%(token)s/\+logout$' % repls, 'logout', name='logout'),

    url(r'^two_factor_auth$', 'twofactor_view', name='twofactor'),
    url(r'^%(token)s/two_factor_auth$' % repls, 'twofactor_view',
        name='twofactor'),

    url(r'^\+new_account$' % repls, 'new_account', name='new_account'),
    url(r'^%(token)s/\+new_account$' % repls, 'new_account',
        name='new_account'),

    url(r'^token/%(authtoken)s/$' % repls, 'claim_token', name='claim_token'),

    url(r'^token/%(authtoken)s/\+resetpassword/%(email_address)s$' % repls,
        'reset_password', name='reset_password'),
    url(r'^%(token)s/token/%(authtoken)s/\+resetpassword/%(email_address)s$'
        % repls, 'reset_password', name='reset_password'),

    url(r'^token/%(authtoken)s/\+newaccount/%(email_address)s$' % repls,
        'permanent_redirect_home'),
    url(r'^confirm-account/%(authtoken)s/%(email_address)s$' % repls,
        'permanent_redirect_home'),
    url(r'^%(token)s/confirm-account/%(authtoken)s/%(email_address)s$' % repls,
        'permanent_redirect_home'),

    url(r'^token/%(authtoken)s/\+newemail/%(email_address)s$' % repls,
        'confirm_email', name='confirm_email'),
    url(r'^%(token)s/token/%(authtoken)s/\+newemail/%(email_address)s$' %
        repls, 'confirm_email', name='confirm_email'),
    url(r'^token/%(authtoken)s/\+newgpgkey/%(fingerprint)s$' % repls,
        'confirm_gpg_key', name='confirm_gpg_key'),
    url(r'^token/%(authtoken)s/\+newsignonlygpgkey/%(fingerprint)s$' % repls,
        'confirm_signonly_gpg_key', name='confirm_signonly_gpg_key'),
    url(r'^\+bad-token', 'bad_token', name='bad_token'),
    url(r'^\+logout-to-confirm', 'logout_to_confirm',
        name='logout_to_confirm'),
    url(r'^\+deactivated$', 'deactivated', name='deactivated'),
    url(r'^\+suspended$', 'suspended', name='suspended'),
    url(r'^\+description$', 'static_page', {'page_name': 'description'},
        name='description'),
    url(r'^\+faq$', 'static_page', {'page_name': 'faq'}, name='faq'),
    url(r'^\+ubuntuone-account$', 'static_page',
        {'page_name': 'ubuntuone-account', 'context': {
            'use_app_links': True
        }}, name='ubuntuone-account'),
    url(r'^combo/$', 'combo_view', name='combo-view'),

    # the urls formerly know as Ubuntu One
    url(r'^one-redirect$', 'static_page', {'page_name': 'one-redirect'},
        name='one-redirect'),
    url(r'^terms/$', 'static_page', {'page_name': 'terms'},
        name='terms_and_conditions'),
    url(r'^terms/embedded/$', 'static_page', {'page_name': 'terms_embedded'},
        name='terms_and_conditions_embedded'),
    url(r'^privacy/$', 'static_page', {'page_name': 'privacy'},
        name='privacy_policy'),
)

urlpatterns += patterns(
    'webui.views.registration',
    url(r'^\+forgot_password$' % repls, 'forgot_password',
        name='forgot_password'),
    url(r'^%(token)s/\+forgot_password$' % repls, 'forgot_password',
        name='forgot_password'),
    url(r'^sync_2fa$' % repls, 'sync_2fa',
        name='sync_2fa'),
)

urlpatterns += patterns(
    'webui.views.account',
    url(r'^$', 'index', name='account-index'),
    url(r'^%(token)s$' % repls, 'index', name='account-index'),
    url(r'^\+emails$', 'account_emails', name='account-emails'),
    url(r'^\+edit$', 'account_edit', name='account-edit'),
    url(r'^%(token)s/\+edit$' % repls, 'index', name='account-edit'),
    url(r'^\+cookie$', 'cookie'),
    url(r'^\+index$' % repls, 'index', name='index'),
    url(r'^%(token)s/\+index$' % repls, 'index', name='index'),
    url(r'^\+new-email$' % repls, 'new_email', name='new_email'),
    url(r'^%(token)s/\+new-email$' % repls, 'new_email', name='new_email'),
    # XXX: deprecated
    url(r'^\+verify-email$' % repls, 'verify_email_by_id',
        name='verify_email_by_id'),
    url(r'^%(token)s/\+verify-email$' % repls, 'verify_email_by_id',
        name='verify_email_by_id'),
    # enddeprecated
    url(r'^verify/%(email_address)s$' % repls, 'verify_email',
        name='verify_email'),
    url(r'^%(token)s/verify/%(email_address)s$' % repls, 'verify_email',
        name='verify_email'),
    url(r'^invalidate-email/%(authtoken)s/%(email_address)s$' % repls,
        'invalidate_email', name='invalidate_email'),
    # XXX: deprecated
    url(r'^\+remove-email$' % repls, 'delete_email_by_id',
        name='delete_email_by_id'),
    url(r'^%(token)s/\+remove-email$' % repls, 'delete_email_by_id',
        name='delete_email_by_id'),
    # enddeprecated
    url(r'^delete/%(email_address)s$' % repls, 'delete_email',
        name='delete_email'),
    url(r'^%(token)s/delete/%(email_address)s$' % repls, 'delete_email',
        name='delete_email'),
    url(r'^\+applications$', 'applications', name='applications'),
    url(r'^\+deactivate$', 'account_deactivate', name='account_deactivate'),
    url(r'^%(token)s/\+deactivate$' % repls, 'account_deactivate',
        name='account_deactivate'),
    url(r'^\+delete$', 'delete_account', name='delete_account'),
    url(r'^activity$', 'auth_log', name='auth_log'),
    url(r'^gpg-keys$', 'gpg_keys', name='gpg_keys'),
    url(r'^ssh-keys$', 'ssh_keys', name='ssh_keys'),
)
# TODO: Support the login-tokens, if it makes sense.
urlpatterns += patterns(
    'webui.views.devices',
    url(r'^device-list$', 'device_list', name='device-list'),
    url(r'^device-addition$', 'device_addition', name='device-addition'),
    url(r'^device-removal/(?P<device_id>.+)$', 'device_removal',
        name='device-removal'),
    url(r'^device-rename/(?P<device_id>.+)$', 'device_rename',
        name='device-rename'),
    url(r'^\+device-help$', 'device_help', name='device-help'),
    url(r'^device-print/(?P<device_id>.+)$', 'device_print',
        name='device-print'),
    url(r'^device-generate/(?P<device_id>.+)$', 'device_generate',
        name='device-generate'),
)

urlpatterns += patterns(
    'webui.views.i18n',
    url(r'^set_language$', 'set_language', name='set_language'),
)

urlpatterns += patterns(
    'webui.views.consumer',
    url(r'^consumer/$', 'start_open_id', name='start_open_id'),
    url(r'^consumer/finish/$', 'finish_open_id', name='finish_open_id'),
    url(r'^consumer/xrds/$', 'rpXRDS', name='rp_xrds'),
)
