# Copyright 2010 Canonical Ltd.  This software is licensed under the
# GNU Affero General Public License version 3 (see the file LICENSE).

from __future__ import unicode_literals

from urllib import quote, unquote

from django.conf import settings
from django.core.urlresolvers import resolve, Resolver404
from django.http import Http404, HttpResponseRedirect
from django.shortcuts import render
from django.views.decorators.http import require_http_methods

from identityprovider.views.server import set_language_info


@require_http_methods(['GET', 'POST'])
def set_language(request):
    next_url = request.POST.get('next', '/')
    if request.method == 'GET':
        return render(
            request, 'select_language.html', {'next': quote(next_url)})

    if not next_url.startswith('/'):
        next_url = '/'
    else:
        try:
            resolve(unquote(next_url))
        except Resolver404:
            next_url = '/'
    lang = request.POST.get('language')

    response = HttpResponseRedirect(next_url)
    if lang not in settings.SUPPORTED_LANGUAGES:
        raise Http404('Unsupported language')

    if request.user.is_authenticated():
        account = request.user
        account.preferredlanguage = lang
        account.save()

    set_language_info(request, response, lang)
    return response
